@@ -128,6 +128,18 @@ TTYBackend::~TTYBackend()
 	DetachNotifyPipe();
 }
 
+static unsigned short GetWinSizeEnv(const char *env, unsigned short def)
+{
+	const char *psz = getenv(env);
+	if (psz && *psz) { // use it if it contains sane integer value
+		int v = atoi(psz);
+		if (v > 10 && v < 4096) {
+			return (unsigned short)v;
+		}
+	}
+	return def;
+}
+
 void TTYBackend::GetWinSize(struct winsize &w)
 {
 	int r = ioctl(_stdout, TIOCGWINSZ, &w);
@@ -135,10 +147,17 @@ void TTYBackend::GetWinSize(struct winsize &w)
 		r = ioctl(_stdin, TIOCGWINSZ, &w);
 		if (UNLIKELY(r != 0)) {
 			perror("TIOCGWINSZ");
-			w.ws_row = g_far2l_term_height;
-			w.ws_col = g_far2l_term_width;
 		}
 	}
+	if (UNLIKELY(r != 0) || (w.ws_row == 0 && w.ws_col == 0)) {
+		// when running over serial console 0:0 is returned always and far2l unusable
+		// try to use $LINES and $COLUMNS if they contain sane values,
+		// otherwise fallback to hardcoded 80:25
+		w.ws_row = GetWinSizeEnv("LINES", g_far2l_term_height);
+		w.ws_col = GetWinSizeEnv("COLUMNS", g_far2l_term_width);
+		fprintf(stderr, "%s: fallback size %u:%u\n",
+			__FUNCTION__, (unsigned int)w.ws_row, (unsigned int)w.ws_col);
+	}
 }
 
 void TTYBackend::DetachNotifyPipe()
@@ -170,41 +189,10 @@ bool TTYBackend::Startup()
 	return true;
 }
 
-static wchar_t s_backend_identification[8] = L"TTY";
-
-static void AppendBackendIdentificationChar(char ch)
+void TTYBackend::BackendInfoChanged()
 {
-	const size_t l = wcslen(s_backend_identification);
-	if (l + 1 >= ARRAYSIZE(s_backend_identification)) {
-		abort();
-	}
-	s_backend_identification[l + 1] = 0;
-	s_backend_identification[l] = (unsigned char)ch;
-}
-
-void TTYBackend::UpdateBackendIdentification()
-{
-	s_backend_identification[3] = 0;
-
-	if (_far2l_tty || _ttyx || _using_extension) {
-		AppendBackendIdentificationChar('|');
-	}
-
-	if (_far2l_tty) {
-		AppendBackendIdentificationChar('F');
-
-	} else if (_ttyx || _using_extension) {
-		if (_ttyx) {
-			AppendBackendIdentificationChar('X');
-		}
-		if (_using_extension) {
-			AppendBackendIdentificationChar(_using_extension);
-		} else if (_ttyx && _ttyx->HasXi()) {
-			AppendBackendIdentificationChar('i');
-		}
-	}
-
-	g_winport_backend = s_backend_identification;
+	std::lock_guard<std::mutex> lock(_backend_info);
+	_backend_info.flavor.clear();
 }
 
 static bool UnderWayland()
@@ -245,7 +233,7 @@ void TTYBackend::ReaderThread()
 				ChooseSimpleClipboardBackend();
 			}
 		}
-		UpdateBackendIdentification();
+		BackendInfoChanged();
 		prev_far2l_tty = _far2l_tty;
 
 		{
@@ -307,11 +295,6 @@ void TTYBackend::ReaderLoop()
 
 		int rs;
 
-		// Enable esc expiration on Wayland as Xi not work there
-		if (!_esc_expiration && UnderWayland()) {
-			_esc_expiration = 100;
-		}
-
 		if (!idle_expired && _esc_expiration > 0 && !_far2l_tty) {
 			struct timeval tv;
 			tv.tv_sec = _esc_expiration / 1000;
@@ -384,7 +367,7 @@ void TTYBackend::WriterThread()
 {
 	bool gone_background = false;
 	try {
-		TTYOutput tty_out(_stdout, _far2l_tty, _norgb);
+		TTYOutput tty_out(_stdout, _far2l_tty, _norgb, _nodetect);
 		DispatchPalette(tty_out);
 //		DispatchTermResized(tty_out);
 		while (!_exiting && !_deadio) {
@@ -810,26 +793,53 @@ DWORD64 TTYBackend::OnConsoleSetTweaks(DWORD64 tweaks)
 
 void TTYBackend::OnConsoleOverrideColor(DWORD Index, DWORD *ColorFG, DWORD *ColorBK)
 {
+	if (Index == (DWORD)-1) {
+		const DWORD64 orig_attrs = g_winport_con_out->GetAttributes();
+		DWORD64 new_attrs = orig_attrs;
+		if ((*ColorFG & 0xff000000) == 0) {
+			SET_RGB_FORE(new_attrs, *ColorFG);
+		}
+		if ((*ColorBK & 0xff000000) == 0) {
+			SET_RGB_BACK(new_attrs, *ColorBK);
+		}
+		if (new_attrs != orig_attrs) {
+			g_winport_con_out->SetAttributes(new_attrs);
+		}
+
+		*ColorFG = ConsoleForeground2RGB(g_winport_palette, orig_attrs & ~(DWORD64)COMMON_LVB_REVERSE_VIDEO).AsRGB();
+		*ColorBK = ConsoleBackground2RGB(g_winport_palette, orig_attrs & ~(DWORD64)COMMON_LVB_REVERSE_VIDEO).AsRGB();
+		return;
+	}
+
 	if (Index >= BASE_PALETTE_SIZE) {
 		fprintf(stderr, "%s: too big index=%u\n", __FUNCTION__, Index);
 		return;
 	}
 
+	const DWORD fg = (*ColorFG == (DWORD)-1) ? g_winport_palette.foreground[Index].AsRGB() : *ColorFG;
+	const DWORD bk = (*ColorBK == (DWORD)-1) ? g_winport_palette.background[Index].AsRGB() : *ColorBK;
+	bool palette_changed = false;
 	{
 		std::unique_lock<std::mutex> lock(_palette_mtx);
-		if (_palette.foreground[Index] == *ColorFG && _palette.background[Index] == *ColorBK) {
-			return;
+		*ColorFG = _palette.foreground[Index];
+		*ColorBK = _palette.background[Index];
+		if (fg != (DWORD)-2 && _palette.foreground[Index] != fg) {
+			_palette.foreground[Index] = fg;
+			palette_changed = true;
+		}
+		if (bk != (DWORD)-2 && _palette.background[Index] != bk) {
+			_palette.background[Index] = bk;
+			palette_changed = true;
 		}
-
-		std::swap(_palette.foreground[Index], *ColorFG);
-		std::swap(_palette.background[Index], *ColorBK);
 	}
 
-	std::unique_lock<std::mutex> lock(_async_mutex);
-	_ae.palette = true;
-	_async_cond.notify_all();
-	while (_ae.palette) {
-		_async_cond.wait(lock);
+	if (palette_changed) {
+		std::unique_lock<std::mutex> lock(_async_mutex);
+		_ae.palette = true;
+		_async_cond.notify_all();
+		while (_ae.palette) {
+			_async_cond.wait(lock);
+		}
 	}
 }
 
@@ -1035,13 +1045,26 @@ void TTYBackend::OnUsingExtension(char extension)
 {
 	if (_using_extension != extension) {
 		_using_extension = extension;
-		UpdateBackendIdentification();
+		BackendInfoChanged();
 	}
 }
 
 void TTYBackend::OnInspectKeyEvent(KEY_EVENT_RECORD &event)
 {
-	if (_ttyx && !_using_extension) {
+	bool in_kernel = 0;
+	// In kernel console use kernel control keys info even if using TTY|X for clipboard
+	#if defined(__linux__) || defined(__FreeBSD__) || defined(__DragonFly__)
+		int kd_mode;
+		#if defined(__linux__)
+		if (ioctl(_stdin, KDGETMODE, &kd_mode) == 0) {
+		#else
+		if (ioctl(_stdin, KDGKBMODE, &kd_mode) == 0) {
+		#endif
+			in_kernel = 1;
+		}
+	#endif
+
+	if (_ttyx && !_using_extension && !in_kernel) {
 		_ttyx->InspectKeyEvent(event);
 
 	} else {
@@ -1204,6 +1227,37 @@ bool TTYBackend::OnConsoleBackgroundMode(bool TryEnterBackgroundMode)
 	return true;
 }
 
+const char *TTYBackend::OnConsoleBackendInfo(int entity)
+{
+	if (entity != -1)
+		return nullptr;
+
+	std::lock_guard<std::mutex> lock(_backend_info);
+	if (_backend_info.flavor.empty()) {
+		_backend_info.flavor.reserve(16); // avoid reallocation ever then
+		_backend_info.flavor = "TTY";
+
+		if (_far2l_tty || _ttyx || _using_extension) {
+			_backend_info.flavor+= '|';
+		}
+
+		if (_far2l_tty) {
+			_backend_info.flavor+= 'F';
+		} else if (_ttyx || _using_extension) {
+			if (_ttyx) {
+				_backend_info.flavor+= 'X';
+			}
+			if (_using_extension) {
+				_backend_info.flavor+= _using_extension;
+			} else if (_ttyx && _ttyx->HasXi()) {
+				_backend_info.flavor+= 'i';
+			}
+		}
+	}
+
+	return _backend_info.flavor.c_str();
+}
+
 
 static void OnSigWinch(int)
 {
