@@ -5,7 +5,6 @@
 #include "TTYInputSequenceParser.h"
 #include "Backend.h"
 
-
 //See:
 // http://www.manmrk.net/tutorials/ISPF/XE/xehelp/html/HID00000579.htm
 // http://www.leonerd.org.uk/hacks/fixterms/
@@ -179,7 +178,7 @@ TTYInputSequenceParser::TTYInputSequenceParser(ITTYInputSpecialSequenceHandler *
 	AddStrF1F5(VK_F2, "Q"); AddStr(VK_F2, 0, "[[B");
 	AddStrF1F5(VK_F3, "R"); AddStr(VK_F3, 0, "[[C");
 	AddStrF1F5(VK_F4, "S"); AddStr(VK_F4, 0, "[[D");
-	AddStrF1F5(VK_F5, "E"); AddStr(VK_F5, 0, "[[E");
+	AddStrF1F5(VK_CLEAR, "E"); AddStr(VK_CLEAR, 0, "[[E"); // NumPad center (5)
 
 	AddStrTilde(VK_HOME, 1);
 	AddStrTilde(VK_INSERT, 2);
@@ -420,6 +419,13 @@ size_t TTYInputSequenceParser::ParseIntoPending(const char *s, size_t l)
 		case 0x01: case 0x02: case 0x03: case 0x04: case 0x05: case 0x06: case 0x07: case 0x08:
 		case 0x0a: case 0x0b: case 0x0c: case 0x0e: case 0x0f: case 0x10: case 0x11: case 0x12:
 		case 0x13: case 0x14: case 0x15: case 0x16: case 0x17: case 0x18: case 0x19: case 0x1a:
+
+			// workaround for \x0a received instead of \x0d in kitty and wezterm in bracketed paste mode
+			if (_bracketed_paste_mode && *s == 0x0a) {
+				AddPendingKeyEvent(TTYInputKey{VK_RETURN, 0});
+				return 1;
+			}
+
 			AddPendingKeyEvent(TTYInputKey{WORD('A' + (*s - 0x01)), LEFT_CTRL_PRESSED});
 			return 1;
 
@@ -464,24 +470,14 @@ size_t TTYInputSequenceParser::ParseIntoPending(const char *s, size_t l)
 
 size_t TTYInputSequenceParser::Parse(const char *s, size_t l, bool idle_expired)
 {
-	//work-around for double encoded mouse events in win32-input mode
+	//work-around for double encoded events in win32-input mode
 	//we encountered sequence \x1B[0;0;27;1;0;1_ it is \x1B encoded in win32 input
-	//following codes are part of some mouse input sequence and must be parsed in separate buffer
-	if ((l > 6 && s[1] == '[' && s[2] == '0' && s[3] == ';' && s[4] == '0' && s[5] == ';') || _win32_accumulate) {
-		size_t r = TryUnwrappWinMouseEscapeSequence(s, l);
-
-		//now we check if _win_mouse_buffer has enough characters for some mouse input sequence
-		if (_win_mouse_buffer.size() > 2 && _win_mouse_buffer[2] == '<') {
-			//seems like SGR extended mouse reporting,
-			//keep accumulate characters until terminator encountered
-			_win32_accumulate = (_win_mouse_buffer.back() == 'M' || _win_mouse_buffer.back() == 'm') ? false : true;
-		} else {
-			//seems like X10 mouse reporting,
-			//keep accumulate characters until we get 6 of them
-			_win32_accumulate = _win_mouse_buffer.size() > 5 ? false : true;
-		}
-
-		return r;
+	//following codes are part of some double encoded input sequence and must be parsed in separate buffer
+	if (
+		(l > 8 && s[1] == '[' && s[2] == '0' && s[3] == ';' && s[4] == '0' && s[5] == ';' && s[6] == '2' && s[7] == '7')
+		|| _win32_accumulate) {
+		_win32_accumulate = true;
+		return TryUnwrappWinDoubleEscapeSequence(s, l);
 	}
 
 	size_t r = ParseIntoPending(s, l);
@@ -671,29 +667,29 @@ void TTYInputSequenceParser::OnBracketedPaste(bool start)
 	ir.EventType = BRACKETED_PASTE_EVENT;
 	ir.Event.BracketedPaste.bStartPaste = start ? TRUE : FALSE;
 	_ir_pending.emplace_back(ir);
+
+	_bracketed_paste_mode = start;
 }
 
-//work-around for double encoded mouse events in win32-input mode
-void TTYInputSequenceParser::ParseWinMouseBuffer(bool idle)
+//work-around for double encoded events in win32-input mode
+void TTYInputSequenceParser::ParseWinDoubleBuffer(bool idle)
 {
-	bool check = false;
-
-	if (_win_mouse_buffer.size() > 2 && _win_mouse_buffer[2] == '<') {
-		//seems like SGR extended mouse reporting,
-		check = (_win_mouse_buffer.back() == 'M' || _win_mouse_buffer.back() == 'm');
-	} else {
-		//seems like X10 mouse reporting,
-		check = (_win_mouse_buffer.size() > 5 && _win_mouse_buffer[2] == 'M');
-	}
-
-	if (check) {
+	if (_win_double_buffer.size() > 1 && _win_double_buffer.back() == 0x1b) {
+		// next sequence already started for some reason
+		// this is not normal, we need to investigate why it happened
 		_win32_accumulate = false;
-		Parse(&_win_mouse_buffer[0], _win_mouse_buffer.size(), idle);
-		_win_mouse_buffer.clear();
-		//fprintf(stderr, "!!!parsed accumulated mouse sequence \n");
-	} else {
+		Parse(&_win_double_buffer[0], _win_double_buffer.size() - 1, idle);
+		_win_double_buffer.erase(_win_double_buffer.begin(), _win_double_buffer.end() - 1);
+		_win32_accumulate = true;
 		return;
 	}
+	
+	if (_win_double_buffer.size() > 2 && _win_double_buffer.back() >= '@' && _win_double_buffer.back() <= '~') {
+		// end of sequence, whatever is it
+		_win32_accumulate = false;
+		Parse(&_win_double_buffer[0], _win_double_buffer.size(), idle);
+		_win_double_buffer.clear();
+	}
 }
 
 //////////////////
