@@ -345,7 +345,7 @@ size_t TTYInputSequenceParser::TryParseAsKittyEscapeSequence(const char *s, size
 			ir.Event.KeyEvent.dwControlKeyState |= ENHANCED_KEY; break;
 		case 'D': ir.Event.KeyEvent.wVirtualKeyCode = VK_LEFT;
 			ir.Event.KeyEvent.dwControlKeyState |= ENHANCED_KEY; break;
-		case 'E': ir.Event.KeyEvent.wVirtualKeyCode = VK_NUMPAD5; break;
+		case 'E': ir.Event.KeyEvent.wVirtualKeyCode = VK_CLEAR; break; // NumPad center (5)
 		case 'H': ir.Event.KeyEvent.wVirtualKeyCode = VK_HOME;
 			ir.Event.KeyEvent.dwControlKeyState |= ENHANCED_KEY; break;
 		case 'F': ir.Event.KeyEvent.wVirtualKeyCode = VK_END;
@@ -378,13 +378,26 @@ size_t TTYInputSequenceParser::TryParseAsKittyEscapeSequence(const char *s, size
 	if ((modif_state & KITTY_MOD_CAPSLOCK) && !(modif_state & KITTY_MOD_SHIFT)) {
 		// it's weird, but kitty can not give us uppercase utf8 in caps lock mode
 		// ("text-as-codepoints" mode should solve it, but it is not working for cyrillic chars for unknown reason)
-		ir.Event.KeyEvent.uChar.UnicodeChar = towupper(ir.Event.KeyEvent.uChar.UnicodeChar);
+		// ir.Event.KeyEvent.uChar.UnicodeChar = towupper(ir.Event.KeyEvent.uChar.UnicodeChar);
+		WINPORT(CharUpperBuff)(&ir.Event.KeyEvent.uChar.UnicodeChar, 1);
 	}
 
 	ir.Event.KeyEvent.bKeyDown = (event_type != KITTY_EVT_KEYUP) ? 1 : 0;
 
 	ir.Event.KeyEvent.wRepeatCount = 0;
 
+	if ((ir.Event.KeyEvent.dwControlKeyState & LEFT_ALT_PRESSED) ||
+		(ir.Event.KeyEvent.dwControlKeyState & RIGHT_ALT_PRESSED)) {
+		switch (ir.Event.KeyEvent.wVirtualKeyCode) {
+			case VK_ESCAPE: case VK_DELETE: case VK_BACK: case VK_TAB: case VK_RETURN: case VK_SPACE:
+				break;
+			default:
+				if (ir.Event.KeyEvent.uChar.UnicodeChar > 0) {
+					WINPORT(CharUpperBuff)(&ir.Event.KeyEvent.uChar.UnicodeChar, 1);
+				}
+		}
+	}
+
 	_ir_pending.emplace_back(ir);
 
 	if (!_using_extension) {
@@ -408,7 +421,7 @@ size_t TTYInputSequenceParser::TryParseAsWinTermEscapeSequence(const char *s, si
 	int args[6] = {0};
 	int args_cnt = 0;
 
-	size_t n;
+	size_t n = 0;
 	for (size_t i = n = 1;; ++i) {
 		if (i == l) {
 			return LIKELY(l < 32) ? TTY_PARSED_WANTMORE : TTY_PARSED_BADSEQUENCE;
@@ -419,8 +432,10 @@ size_t TTYInputSequenceParser::TryParseAsWinTermEscapeSequence(const char *s, si
 			}
 			if (i > n) {
 				args[args_cnt] = atoi(&s[n]);
-				++args_cnt;
+			} else {
+				args[args_cnt] = 0;
 			}
+			++args_cnt;
 			n = i + 1;
 			if (s[i] == '_') {
 				break;
@@ -431,22 +446,15 @@ size_t TTYInputSequenceParser::TryParseAsWinTermEscapeSequence(const char *s, si
 		}
 	}
 
-
-
-	//do not create invalid input event
-	//wVirtualKeyCode, wVirtualScanCode 0 with bKeyDown 1 doesn't make sense
-	if ( !((args[0] == 0) && (args[1] == 0) && (args[3] == 1) && (args[4] == 0)) )
-	{
-		INPUT_RECORD ir = {};
-		ir.EventType = KEY_EVENT;
-		ir.Event.KeyEvent.wVirtualKeyCode = args[0];
-		ir.Event.KeyEvent.wVirtualScanCode = args[1];
-		ir.Event.KeyEvent.uChar.UnicodeChar = args[2];
-		ir.Event.KeyEvent.bKeyDown = (args[3] ? TRUE : FALSE);
-		ir.Event.KeyEvent.dwControlKeyState = args[4];
-		ir.Event.KeyEvent.wRepeatCount = args[5];
-		_ir_pending.emplace_back(ir);
-	}
+	INPUT_RECORD ir = {};
+	ir.EventType = KEY_EVENT;
+	ir.Event.KeyEvent.wVirtualKeyCode = args[0] ? args[0] : VK_UNASSIGNED;
+	ir.Event.KeyEvent.wVirtualScanCode = args[1];
+	ir.Event.KeyEvent.uChar.UnicodeChar = args[2];
+	ir.Event.KeyEvent.bKeyDown = (args[3] ? TRUE : FALSE);
+	ir.Event.KeyEvent.dwControlKeyState = args[4];
+	ir.Event.KeyEvent.wRepeatCount = args[5];
+	_ir_pending.emplace_back(ir);
 
 	if (!_using_extension) {
 		fprintf(stderr, "TTYInputSequenceParser: using WinTerm extension\n");
@@ -460,12 +468,12 @@ size_t TTYInputSequenceParser::TryParseAsWinTermEscapeSequence(const char *s, si
 //maybe it will be better not copy/paste TryParseAsWinTermEscapeSequence here
 //but passing yet another flag to it is less readable.
 //so keep it this way until microsoft fix their stuff in the win32-input protocol
-size_t TTYInputSequenceParser::TryUnwrappWinMouseEscapeSequence(const char *s, size_t l)
+size_t TTYInputSequenceParser::TryUnwrappWinDoubleEscapeSequence(const char *s, size_t l)
 {
 	int args[6] = {0};
 	int args_cnt = 0;
 
-	size_t n;
+	size_t n = 0;
 	for (size_t i = n = 1;; ++i) {
 		if (i == l) {
 			//fprintf(stderr, "\nwant mooore characters... \n");
@@ -477,8 +485,10 @@ size_t TTYInputSequenceParser::TryUnwrappWinMouseEscapeSequence(const char *s, s
 			}
 			if (i > n) {
 				args[args_cnt] = atoi(&s[n]);
-				++args_cnt;
+			} else {
+				args[args_cnt] = 0;
 			}
+			++args_cnt;
 			n = i + 1;
 			if (s[i] == '_') {
 				break;
@@ -491,7 +501,7 @@ size_t TTYInputSequenceParser::TryUnwrappWinMouseEscapeSequence(const char *s, s
 
 	if(args[2] > 0 && args[3] == 1){ // only KeyDown and valid char should pass
 		//fprintf(stderr, "Parsed: ==%c==\n", (unsigned char)(args[2]));
-		_win_mouse_buffer.push_back((unsigned char)args[2]);
+		_win_double_buffer.push_back((unsigned char)args[2]);
 	}
 
 	return n;
