@@ -1,4 +1,5 @@
 #include "wxMain.h"
+#include <dlfcn.h>
 
 #define AREAS_REDUCTION
 
@@ -22,6 +23,10 @@
 // If time between adhoc text copy and mouse button release less then this value then text will not be copied. Used to protect against unwanted copy-paste-s
 #define QEDIT_COPY_MINIMAL_DELAY 150
 
+// This defines how much time UI remain frozen after user released qedit, that
+// allows user to quickly select another location before all shadowed output changes applied
+#define QEDIT_UNFREEZE_DELAY     1000
+
 #if (wxCHECK_VERSION(3, 0, 5) || (wxCHECK_VERSION(3, 0, 4) && WX304PATCH)) && !(wxCHECK_VERSION(3, 1, 0) && !wxCHECK_VERSION(3, 1, 3))
 	// wx version is greater than 3.0.5 (3.0.4 on Ubuntu 20) and not in 3.1.0-3.1.2
 	#define WX_ALT_NONLATIN
@@ -43,6 +48,9 @@ static DWORD g_TIMER_IDLING_CYCLES = TIMER_IDLING_TIME / DEF_TIMER_PERIOD;
 
 bool WinPortClipboard_IsBusy();
 
+WINPORT_DECL_DEF(FreezeConsoleOutput,VOID,())
+WINPORT_DECL_DEF(UnfreezeConsoleOutput,VOID,())
+
 static void NormalizeArea(SMALL_RECT &area)
 {
 	if (area.Left > area.Right) std::swap(area.Left, area.Right);
@@ -572,6 +580,32 @@ wxEND_EVENT_TABLE()
 WinPortPanel::WinPortPanel(WinPortFrame *frame, const wxPoint& pos, const wxSize& size)
 	: _paint_context(this), _frame(frame), _refresh_rects_throttle(WINPORT(GetTickCount)())
 {
+	_backend_info.emplace_back(
+		StrPrintf("Build/wxWidgets %d.%d.%d", wxMAJOR_VERSION, wxMINOR_VERSION, wxRELEASE_NUMBER));
+
+#if wxCHECK_VERSION(2, 9, 2)
+	wxVersionInfo wxv = wxGetLibraryVersionInfo();
+	_backend_info.emplace_back(
+		StrPrintf("wxWidgets %d.%d.%d", wxv.GetMajor(), wxv.GetMinor(), wxv.GetMicro()));
+	fprintf(stderr, "FAR2L wxWidgets build: %d.%d.%d actual: %d.%d.%d\n",
+		wxMAJOR_VERSION, wxMINOR_VERSION, wxRELEASE_NUMBER, wxv.GetMajor(), wxv.GetMinor(), wxv.GetMicro());
+#else
+	fprintf(stderr, "FAR2L wxWidgets build: %d.%d.%d\n", wxMAJOR_VERSION, wxMINOR_VERSION, wxRELEASE_NUMBER);
+#endif
+
+#ifdef __WXGTK__
+	typedef unsigned int (*gtk_get_x_version_t)(void);
+	gtk_get_x_version_t pfn_gtk_get_major_version = (gtk_get_x_version_t)dlsym(RTLD_DEFAULT, "gtk_get_major_version");
+	if (pfn_gtk_get_major_version) {
+		gtk_get_x_version_t pfn_gtk_get_minor_version = (gtk_get_x_version_t)dlsym(RTLD_DEFAULT, "gtk_get_minor_version");
+		gtk_get_x_version_t pfn_gtk_get_micro_version = (gtk_get_x_version_t)dlsym(RTLD_DEFAULT, "gtk_get_micro_version");
+		_backend_info.emplace_back(
+			StrPrintf("GTK %d.%d.%d", pfn_gtk_get_major_version(),
+				pfn_gtk_get_minor_version ? pfn_gtk_get_minor_version() : -1,
+				pfn_gtk_get_micro_version ? pfn_gtk_get_micro_version() : -1));
+	}
+#endif
+
 	// far2l doesn't need special erase background
 	SetBackgroundStyle(wxBG_STYLE_PAINT);
 	Create(frame, wxID_ANY, pos, size, wxWANTS_CHARS | wxNO_BORDER);
@@ -761,6 +795,12 @@ void WinPortPanel::OnTimerPeriodic(wxTimerEvent& event)
 		return;
 	}
 
+	if (_qedit_unfreeze_start_ticks != 0
+			&& WINPORT(GetTickCount)() - _qedit_unfreeze_start_ticks >= QEDIT_UNFREEZE_DELAY) {
+		WINPORT(UnfreezeConsoleOutput)();
+		_qedit_unfreeze_start_ticks = 0;
+	}
+
 	CheckForResizePending();
 	CheckPutText2CLip();	
 	if (_mouse_qedit_start_ticks != 0 && WINPORT(GetTickCount)() - _mouse_qedit_start_ticks > QEDIT_COPY_MINIMAL_DELAY) {
@@ -769,7 +809,10 @@ void WinPortPanel::OnTimerPeriodic(wxTimerEvent& event)
 	_paint_context.BlinkCursor();
 	++_timer_idling_counter;
 	// stop timer if counter reached limit and cursor is visible and no other timer-dependent things remained
-	if (_timer_idling_counter >= g_TIMER_IDLING_CYCLES && _paint_context.CursorBlinkState() && _text2clip.empty()) {
+	if (_timer_idling_counter >= g_TIMER_IDLING_CYCLES
+			&& _paint_context.CursorBlinkState()
+			&& _qedit_unfreeze_start_ticks == 0
+			&& _text2clip.empty()) {
 		_periodic_timer->Stop();
 	}
 }
@@ -827,11 +870,11 @@ void WinPortPanel::OnConsoleOutputUpdated(const SMALL_RECT *areas, size_t count)
 		if (_refresh_rects.empty()) {
 			action = A_QUEUE;
 #ifndef __APPLE__
-		} else if (_refresh_rects_throttle != (DWORD)-1 &&
+		} else if (_refresh_rects_throttle != 0 &&
 				WINPORT(GetTickCount)() - _refresh_rects_throttle > 500 &&
 				!wxIsMainThread()) {
 			action = A_THROTTLE;
-			_refresh_rects_throttle = (DWORD)-1;
+			_refresh_rects_throttle = 0;
 #else
 //TODO: fix stuck
 #endif
@@ -915,8 +958,6 @@ void WinPortPanel::OnConsoleOutputUpdated(const SMALL_RECT *areas, size_t count)
 			CallInMain<int>(fn);
 			std::lock_guard<std::mutex> lock(_refresh_rects);
 			_refresh_rects_throttle = WINPORT(GetTickCount)();
-			if (_refresh_rects_throttle == (DWORD)-1)
-				_refresh_rects_throttle = 0;
 		} break;
 		
 		case A_NOTHING: break;
@@ -1109,14 +1150,197 @@ static bool IsForcedCharTranslation(int code)
 		|| code==WXK_NUMPAD_MULTIPLY || code==WXK_NUMPAD_SUBTRACT || code==WXK_NUMPAD_DIVIDE);
 }
 
+// helper function that returns textual description of wx virtual keycode
+const char* GetWxVirtualKeyCodeName(int keycode)
+{
+	switch ( keycode )
+	{
+#define WXK_(x) \
+		case WXK_##x: return #x;
+
+		WXK_(BACK)
+		WXK_(TAB)
+		WXK_(RETURN)
+		WXK_(ESCAPE)
+		WXK_(SPACE)
+		WXK_(DELETE)
+		WXK_(START)
+		WXK_(LBUTTON)
+		WXK_(RBUTTON)
+		WXK_(CANCEL)
+		WXK_(MBUTTON)
+//		WXK_(NUMPAD_CENTER)
+		WXK_(SHIFT)
+		WXK_(ALT)
+		WXK_(CONTROL)
+		WXK_(MENU)
+		WXK_(PAUSE)
+		WXK_(CAPITAL)
+		WXK_(END)
+		WXK_(HOME)
+		WXK_(LEFT)
+		WXK_(UP)
+		WXK_(RIGHT)
+		WXK_(DOWN)
+		WXK_(SELECT)
+		WXK_(PRINT)
+		WXK_(EXECUTE)
+		WXK_(SNAPSHOT)
+		WXK_(INSERT)
+		WXK_(HELP)
+		WXK_(NUMPAD0)
+		WXK_(NUMPAD1)
+		WXK_(NUMPAD2)
+		WXK_(NUMPAD3)
+		WXK_(NUMPAD4)
+		WXK_(NUMPAD5)
+		WXK_(NUMPAD6)
+		WXK_(NUMPAD7)
+		WXK_(NUMPAD8)
+		WXK_(NUMPAD9)
+		WXK_(MULTIPLY)
+		WXK_(ADD)
+		WXK_(SEPARATOR)
+		WXK_(SUBTRACT)
+		WXK_(DECIMAL)
+		WXK_(DIVIDE)
+		WXK_(F1)
+		WXK_(F2)
+		WXK_(F3)
+		WXK_(F4)
+		WXK_(F5)
+		WXK_(F6)
+		WXK_(F7)
+		WXK_(F8)
+		WXK_(F9)
+		WXK_(F10)
+		WXK_(F11)
+		WXK_(F12)
+		WXK_(F13)
+		WXK_(F14)
+		WXK_(F15)
+		WXK_(F16)
+		WXK_(F17)
+		WXK_(F18)
+		WXK_(F19)
+		WXK_(F20)
+		WXK_(F21)
+		WXK_(F22)
+		WXK_(F23)
+		WXK_(F24)
+		WXK_(NUMLOCK)
+		WXK_(SCROLL)
+		WXK_(PAGEUP)
+		WXK_(PAGEDOWN)
+		WXK_(NUMPAD_SPACE)
+		WXK_(NUMPAD_TAB)
+		WXK_(NUMPAD_ENTER)
+		WXK_(NUMPAD_F1)
+		WXK_(NUMPAD_F2)
+		WXK_(NUMPAD_F3)
+		WXK_(NUMPAD_F4)
+		WXK_(NUMPAD_HOME)
+		WXK_(NUMPAD_LEFT)
+		WXK_(NUMPAD_UP)
+		WXK_(NUMPAD_RIGHT)
+		WXK_(NUMPAD_DOWN)
+		WXK_(NUMPAD_PAGEUP)
+		WXK_(NUMPAD_PAGEDOWN)
+		WXK_(NUMPAD_END)
+		WXK_(NUMPAD_INSERT)
+		WXK_(NUMPAD_DELETE)
+		WXK_(NUMPAD_EQUAL)
+		WXK_(NUMPAD_MULTIPLY)
+		WXK_(NUMPAD_ADD)
+		WXK_(NUMPAD_SEPARATOR)
+		WXK_(NUMPAD_SUBTRACT)
+		WXK_(NUMPAD_DECIMAL)
+		WXK_(NUMPAD_DIVIDE)
+
+		WXK_(WINDOWS_LEFT)
+		WXK_(WINDOWS_RIGHT)
+#ifdef __WXOSX__
+		WXK_(RAW_CONTROL)
+#endif
+#undef WXK_
+
+	default:
+
+		static char buffer[20] = {0};
+		snprintf(buffer, sizeof(buffer),
+			((keycode >= 20) && (keycode <= 0x7f)) ? "\"%c\"" : "%d", keycode);
+		return buffer;
+	}
+}
+
+char* FormatWxKeyState(uint16_t state) {
+
+	static char buffer[5];
+
+	buffer[0]  = state & wxMOD_ALT          ? 'A' : 'a';
+	buffer[1]  = state & wxMOD_CONTROL      ? 'C' : 'c';
+	buffer[2]  = state & wxMOD_SHIFT        ? 'S' : 's';
+	buffer[3]  = state & wxMOD_META         ? 'M' : 'm';
+
+	buffer[4] = '\0';
+
+	return buffer;
+}
+
+static bool isNumpadNumericKey(int keycode)
+{
+	switch (keycode) {
+		case WXK_NUMPAD0:
+		case WXK_NUMPAD1:
+		case WXK_NUMPAD2:
+		case WXK_NUMPAD3:
+		case WXK_NUMPAD4:
+		case WXK_NUMPAD5:
+		case WXK_NUMPAD6:
+		case WXK_NUMPAD7:
+		case WXK_NUMPAD8:
+		case WXK_NUMPAD9:
+		case WXK_NUMPAD_INSERT:
+		case WXK_NUMPAD_END:
+		case WXK_NUMPAD_DOWN:
+		case WXK_NUMPAD_PAGEDOWN:
+		case WXK_NUMPAD_LEFT:
+		case WXK_NUMPAD_BEGIN: // NumPad center (5)
+		case WXK_NUMPAD_RIGHT:
+		case WXK_NUMPAD_HOME:
+		case WXK_NUMPAD_UP:
+		case WXK_NUMPAD_PAGEUP:
+			return true;
+		default:
+			return false;
+	}
+}
+
+bool isLayoutDependentKey( wxKeyEvent& event ) {
+	switch (event.GetKeyCode()) {
+		// Those keys generate Unicode key codes, but they are not keyboard layout-dependent keys
+		case WXK_ESCAPE:
+		case WXK_DELETE:
+		case WXK_BACK:
+		case WXK_TAB:
+		case WXK_RETURN:
+		case WXK_SPACE:
+			return false;
+		default:
+			return event.GetUnicodeKey() > 0;
+	}
+}
+
 void WinPortPanel::OnKeyDown( wxKeyEvent& event )
 {
 	ResetTimerIdling();
 	DWORD now = WINPORT(GetTickCount)();
 	const auto uni = event.GetUnicodeKey();
-	fprintf(stderr, "OnKeyDown: raw=%x code=%x uni=%x (%lc) ts=%lu [now=%u]",
+	fprintf(stderr, "\nOnKeyDown: %s %s raw=%x code=%x uni=%x \"%lc\" ts=%lu [now=%u]",
+		FormatWxKeyState(event.GetModifiers()),
+		GetWxVirtualKeyCodeName(event.GetKeyCode()),
 		event.GetRawKeyCode(), event.GetKeyCode(),
-		uni, (uni > 0x1f) ? uni : L' ', event.GetTimestamp(), now);
+		uni, (uni > 0x1f) ? uni : L'?', event.GetTimestamp(), now);
 
 	_exclusive_hotkeys.OnKeyDown(event, _frame);
 
@@ -1169,8 +1393,15 @@ void WinPortPanel::OnKeyDown( wxKeyEvent& event )
 	// also it didnt cause problems yet
 	if ( (_key_tracker.Shift() && !event.ShiftDown())
 		|| ((_key_tracker.LeftControl() || _key_tracker.RightControl()) && !event.ControlDown())) {
-		if (_key_tracker.CheckForSuddenModifiersUp()) {
-			_exclusive_hotkeys.Reset();
+
+		if (
+#ifndef __WXOSX__
+			(!_key_tracker.Alt() || _key_tracker.Shift() || _key_tracker.LeftControl() || _key_tracker.RightControl()
+			|| !isNumpadNumericKey(event.GetKeyCode()) || g_wayland) && // workaround for #2294, 2464
+#endif
+
+				_key_tracker.CheckForSuddenModifiersUp()) {
+					_exclusive_hotkeys.Reset();
 		}
 	}
 
@@ -1201,8 +1432,16 @@ void WinPortPanel::OnKeyDown( wxKeyEvent& event )
 	}
 #endif
 
+	// We can not trust OnKeyDown Unicode character value for Alt+letter due to wx issue #23421,
+	// so let's fall back to OnChar value for such key combinations.
+
 	if ( (dwMods != 0 && event.GetUnicodeKey() < 32)
-		|| (dwMods & (LEFT_CTRL_PRESSED | RIGHT_CTRL_PRESSED | LEFT_ALT_PRESSED)) != 0
+		|| ((dwMods & (LEFT_CTRL_PRESSED | RIGHT_CTRL_PRESSED | LEFT_ALT_PRESSED))
+#if !defined(__WXOSX__) && wxCHECK_VERSION(3, 2, 3) // workaround is still needed at least in wx 3.2.6, see wx issue #24772
+
+			&& (/*g_wayland ||*/ !event.AltDown() || !isLayoutDependentKey(event)) // workaround for wx issue #23421
+#endif
+			)
 		|| event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_RETURN
 		|| (event.GetUnicodeKey()==WXK_NONE && !IsForcedCharTranslation(event.GetKeyCode()) ))
 	{
@@ -1226,6 +1465,8 @@ void WinPortPanel::OnKeyDown( wxKeyEvent& event )
 	}
 #endif
 
+	_enqueued_in_onchar = false;
+
 	event.Skip();
 }
 
@@ -1233,12 +1474,20 @@ void WinPortPanel::OnKeyUp( wxKeyEvent& event )
 {
 	ResetTimerIdling();
 	const auto uni = event.GetUnicodeKey();
-	fprintf(stderr, "OnKeyUp: raw=%x code=%x uni=%x (%lc) ts=%lu",
+	fprintf(stderr, "\nOnKeyUp: %s %s raw=%x code=%x uni=%x \"%lc\" ts=%lu",
+		FormatWxKeyState(event.GetModifiers()),
+		GetWxVirtualKeyCodeName(event.GetKeyCode()),
 		event.GetRawKeyCode(), event.GetKeyCode(),
-		uni, (uni > 0x1f) ? uni : L' ', event.GetTimestamp());
+		uni, (uni > 0x1f) ? uni : L'?', event.GetTimestamp());
 
 	_exclusive_hotkeys.OnKeyUp(event);
 
+	if (_enqueued_in_onchar) {
+		_enqueued_in_onchar = false;
+		fprintf(stderr, " IN_ONCHAR\n");
+		return;
+	}
+
 	if (event.GetSkipped()) {
 		fprintf(stderr, " SKIPPED\n");
 		return;
@@ -1299,10 +1548,23 @@ void WinPortPanel::OnKeyUp( wxKeyEvent& event )
 			ir.Event.KeyEvent.bKeyDown = TRUE;
 		}
 #endif
-		wxConsoleInputShim::Enqueue(&ir, 1);
+
+#if !defined(__WXOSX__) && wxCHECK_VERSION(3, 2, 3)
+		if (/*g_wayland ||*/ !event.AltDown() || !isLayoutDependentKey(event)) { // workaround for wx issue #23421
+#else
+		{
+#endif
+			wxConsoleInputShim::Enqueue(&ir, 1);
+		}
+
 	}
-	if (_key_tracker.CheckForSuddenModifiersUp()) {
-		_exclusive_hotkeys.Reset();
+	if (
+#ifndef __WXOSX__
+		(!_key_tracker.Alt() || _key_tracker.Shift() || _key_tracker.LeftControl() || _key_tracker.RightControl()
+		|| !isNumpadNumericKey(event.GetKeyCode()) || g_wayland) && // workaround for #2294, 2464
+#endif
+		_key_tracker.CheckForSuddenModifiersUp()) {
+			_exclusive_hotkeys.Reset();
 	}
 	//event.Skip();
 }
@@ -1311,9 +1573,14 @@ void WinPortPanel::OnChar( wxKeyEvent& event )
 {
 	ResetTimerIdling();
 	const auto uni = event.GetUnicodeKey();
-	fprintf(stderr, "OnChar: raw=%x code=%x uni=%x (%lc) ts=%lu lke=%u",
+	if (_key_tracker.LastKeydown().GetTimestamp() != event.GetTimestamp()) {
+		fprintf(stderr, "\n");
+	}
+	fprintf(stderr, "\nOnChar: %s %s raw=%x code=%x uni=%x \"%lc\" ts=%lu lke=%u",
+		FormatWxKeyState(event.GetModifiers()),
+		GetWxVirtualKeyCodeName(event.GetKeyCode()),
 		event.GetRawKeyCode(), event.GetKeyCode(),
-		uni, (uni > 0x1f) ? uni : L' ', event.GetTimestamp(), _last_keydown_enqueued);
+		uni, (uni > 0x1f) ? uni : L'?', event.GetTimestamp(), _last_keydown_enqueued);
 	_exclusive_hotkeys.OnKeyUp(event);
 
 	if (event.GetSkipped()) {
@@ -1343,12 +1610,35 @@ void WinPortPanel::OnChar( wxKeyEvent& event )
 		}
 		ir.Event.KeyEvent.uChar.UnicodeChar = event.GetUnicodeKey();
 
+#if !defined(__WXOSX__) && wxCHECK_VERSION(3, 2, 3)
+		if (event.AltDown() && isLayoutDependentKey(event)) {
+
+			// workaround for wx issue #23421
+
+			// OnChar KeyCode value is empty for non-latin letters in older wx so let's use value from previous KeyDown
+			// See wx issue #23379 for details
+			wx2INPUT_RECORD ir_tmp(TRUE, _key_tracker.LastKeydown(), _key_tracker);
+			ir.Event.KeyEvent.wVirtualKeyCode = ir_tmp.Event.KeyEvent.wVirtualKeyCode;
+			ir.Event.KeyEvent.wVirtualScanCode = ir_tmp.Event.KeyEvent.wVirtualScanCode;
+			ir.Event.KeyEvent.dwControlKeyState = ir_tmp.Event.KeyEvent.dwControlKeyState;
+			ir.Event.KeyEvent.dwControlKeyState |= LEFT_ALT_PRESSED;
+			WINPORT(CharUpperBuff)(&ir.Event.KeyEvent.uChar.UnicodeChar, 1);
+		}
+#endif
+
 		ir.Event.KeyEvent.bKeyDown = TRUE;
 		wxConsoleInputShim::Enqueue(&ir, 1);
 		
 		ir.Event.KeyEvent.bKeyDown = FALSE;
 		wxConsoleInputShim::Enqueue(&ir, 1);
-		
+
+		_enqueued_in_onchar = true;
+
+#if !defined(__WXOSX__)
+		// avoid double up event in ResetInputState()
+		wxKeyEvent keyEventCopy = _key_tracker.LastKeydown();
+		_key_tracker.OnKeyUp(keyEventCopy);
+#endif
 	}
 	//event.Skip();
 }
@@ -1516,8 +1806,13 @@ void WinPortPanel::OnMouseQEdit( wxMouseEvent &event, COORD pos_char )
 		_mouse_qedit_start_ticks = WINPORT(GetTickCount)();
 		if (!_mouse_qedit_start_ticks) _mouse_qedit_start_ticks = 1;
 		_mouse_qedit_moved = false;
+		if (_qedit_unfreeze_start_ticks == 0) {
+			WINPORT(FreezeConsoleOutput)();
+		} else {
+			_qedit_unfreeze_start_ticks = 0;
+		}
 		DamageAreaBetween(_mouse_qedit_start, _mouse_qedit_last);
-		
+
 	} else if (_mouse_qedit_start_ticks != 0) {
 		if (event.Moving() || event.Dragging()) {
 			DamageAreaBetween(_mouse_qedit_start, _mouse_qedit_last);
@@ -1561,6 +1856,7 @@ void WinPortPanel::OnMouseQEdit( wxMouseEvent &event, COORD pos_char )
 			_mouse_qedit_start_ticks = 0;
 			DamageAreaBetween(_mouse_qedit_start, _mouse_qedit_last);
 			DamageAreaBetween(_mouse_qedit_start, pos_char);
+			_qedit_unfreeze_start_ticks = WINPORT(GetTickCount)();
 		}
 	}
 }
@@ -1761,6 +2057,24 @@ void WinPortPanel::OnConsoleSetCursorBlinkTime(DWORD interval)
 		wxQueueEvent(this, event);
 }
 
+const char *WinPortPanel::OnConsoleBackendInfo(int entity)
+{
+	if (entity == -1) {
+		return "GUI";
+	}
+
+	if (entity < 0) {
+		return nullptr;
+	}
+
+	if (size_t(entity) >= _backend_info.size()) {
+		return nullptr;
+	}
+
+	return _backend_info[size_t(entity)].c_str();
+}
+
+
 void WinPortPanel::CheckPutText2CLip()
 {
 	if (!_text2clip.empty()) {
@@ -1804,6 +2118,24 @@ void WinPortPanel::ResetInputState()
 
 static void ConsoleOverrideColorInMain(DWORD Index, DWORD *ColorFG, DWORD *ColorBK)
 {
+	if (Index == (DWORD)-1) {
+		const DWORD64 orig_attrs = g_winport_con_out->GetAttributes();
+		DWORD64 new_attrs = orig_attrs;
+		if ((*ColorFG & 0xff000000) == 0) {
+			SET_RGB_FORE(new_attrs, *ColorFG);
+		}
+		if ((*ColorBK & 0xff000000) == 0) {
+			SET_RGB_BACK(new_attrs, *ColorBK);
+		}
+		if (new_attrs != orig_attrs) {
+			g_winport_con_out->SetAttributes(new_attrs);
+		}
+
+		*ColorFG = WxConsoleForeground2RGB(orig_attrs & ~(DWORD64)COMMON_LVB_REVERSE_VIDEO).AsRGB();
+		*ColorBK = WxConsoleBackground2RGB(orig_attrs & ~(DWORD64)COMMON_LVB_REVERSE_VIDEO).AsRGB();
+		return;
+	}
+
 	WinPortRGB fg(*ColorFG), bk(*ColorBK);
 	if (*ColorFG == (DWORD)-1) {
 		fg = g_winport_palette.foreground[Index];
@@ -1811,10 +2143,16 @@ static void ConsoleOverrideColorInMain(DWORD Index, DWORD *ColorFG, DWORD *Color
 	if (*ColorBK == (DWORD)-1) {
 		bk = g_winport_palette.background[Index];
 	}
-	*ColorFG = g_wx_palette.foreground[Index].AsRGB();
-	*ColorBK = g_wx_palette.background[Index].AsRGB();
-	g_wx_palette.foreground[Index] = fg;
-	g_wx_palette.background[Index] = bk;
+	const auto prev_fg = g_wx_palette.foreground[Index].AsRGB();
+	const auto prev_bk = g_wx_palette.background[Index].AsRGB();
+	if (*ColorFG != (DWORD)-2) {
+		g_wx_palette.foreground[Index] = fg;
+	}
+	if (*ColorBK != (DWORD)-2) {
+		g_wx_palette.background[Index] = bk;
+	}
+	*ColorFG = prev_fg;
+	*ColorBK = prev_bk;
 }
 
 static void ConsoleOverrideBasePaletteInMain(void *pbuff)
