@@ -5,4 +5,7 @@ const char16_t HrdNameDefault[] = u"default\0";
 const char16_t HrdClassRgb[] = u"rgb\0";
 const char16_t HrdClassText[] = u"text\0";
 
+UNICODE_LITERAL(jar, u"jar:")
+//inline const auto jar = UnicodeString(u"jar:");
+
 #endif  // COLORER_BASENAMES_H
