@@ -1,8 +1,12 @@
 #include "colorer/parsers/FileTypeImpl.h"
+#include <memory>
 
-FileType::Impl::Impl(UnicodeString name, UnicodeString group, UnicodeString description)
-    : name(std::move(name)), group(std::move(group)), description(std::move(description))
+FileType::Impl::Impl(UnicodeString l_name, UnicodeString l_group, UnicodeString l_description)
+    : name(std::move(l_name)), group(std::move(l_group)), description(std::move(l_description))
 {
+  if (name.isEmpty()) {
+    throw FileTypeException("The file type name must not be empty");
+  }
 }
 
 const UnicodeString& FileType::Impl::getName() const
@@ -20,19 +24,22 @@ const UnicodeString& FileType::Impl::getDescription() const
   return description;
 }
 
-void FileType::Impl::setName(const UnicodeString* param_name)
+void FileType::Impl::setName(const UnicodeString& param_name)
 {
-  name = *param_name;
+  if (param_name.isEmpty()) {
+    throw FileTypeException("The file type name must not be empty");
+  }
+  name = param_name;
 }
 
-void FileType::Impl::setGroup(const UnicodeString* group_name)
+void FileType::Impl::setGroup(const UnicodeString& group_name)
 {
-  group = *group_name;
+  group = group_name;
 }
 
-void FileType::Impl::setDescription(const UnicodeString* description_)
+void FileType::Impl::setDescription(const UnicodeString& value)
 {
-  description = *description_;
+  description = value;
 }
 
 Scheme* FileType::Impl::getBaseScheme() const
@@ -52,7 +59,7 @@ std::vector<UnicodeString> FileType::Impl::enumParams() const
 
 const UnicodeString* FileType::Impl::getParamDescription(const UnicodeString& param_name) const
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end() && tp->second.description) {
     return tp->second.description.get();
   }
@@ -61,9 +68,9 @@ const UnicodeString* FileType::Impl::getParamDescription(const UnicodeString& pa
 
 const UnicodeString* FileType::Impl::getParamValue(const UnicodeString& param_name) const
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end()) {
-    if (tp->second.user_value && tp->second.user_value) {
+    if (tp->second.user_value) {
       return tp->second.user_value.get();
     }
     return &tp->second.value;
@@ -71,17 +78,16 @@ const UnicodeString* FileType::Impl::getParamValue(const UnicodeString& param_na
   return nullptr;
 }
 
-int FileType::Impl::getParamValueInt(const UnicodeString& param_name, int def) const
+int FileType::Impl::getParamValueInt(const UnicodeString& param_name, const int def) const
 {
   int val = def;
-  auto param_value = getParamValue(param_name);
+  const auto* param_value = getParamValue(param_name);
   if (param_value && param_value->length() > 0) {
     auto param_str = UStr::to_stdstr(param_value);
     try {
       val = std::stoi(param_str, nullptr);
     } catch (std::exception&) {
-      logger->error("Error parse param {0} with value {1} to integer number", param_name,
-                    param_str);
+      COLORER_LOG_ERROR("Error parse param '%' with value '%' to integer number", param_name, param_str);
     }
   }
   return val;
@@ -89,7 +95,7 @@ int FileType::Impl::getParamValueInt(const UnicodeString& param_name, int def) c
 
 const UnicodeString* FileType::Impl::getParamDefaultValue(const UnicodeString& param_name) const
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end()) {
     return &tp->second.value;
   }
@@ -98,7 +104,7 @@ const UnicodeString* FileType::Impl::getParamDefaultValue(const UnicodeString& p
 
 const UnicodeString* FileType::Impl::getParamUserValue(const UnicodeString& param_name) const
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end() && tp->second.user_value) {
     return tp->second.user_value.get();
   }
@@ -113,36 +119,31 @@ TypeParameter& FileType::Impl::addParam(const UnicodeString& param_name, const U
 
 void FileType::Impl::setParamValue(const UnicodeString& param_name, const UnicodeString* value)
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end()) {
     if (value) {
-      tp->second.user_value.reset(new UnicodeString(*value));
+      tp->second.user_value = std::make_unique<UnicodeString>(*value);
     }
     else {
       tp->second.user_value.reset();
     }
   }
   else {
-    throw FileTypeException("Don`t set value " + *value + " for parameter \"" + param_name +
-                            "\". Parameter not exists.");
+    throw FileTypeException("Don`t set new value for parameter \"" + param_name + "\". Parameter not exists.");
   }
 }
 
-void FileType::Impl::setParamDefaultValue(const UnicodeString& param_name,
-                                          const UnicodeString* value)
+void FileType::Impl::setParamDefaultValue(const UnicodeString& param_name, const UnicodeString* value)
 {
-  auto tp = paramsHash.find(param_name);
+  if (!value) {
+    throw FileTypeException("You can`t set the default value to null for the parameter \"" + param_name + "\"");
+  }
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end()) {
-    if (value) {
-      tp->second.value = *value;
-    }
-    else {
-      throw FileTypeException("Don`t set null value for parameter \"" + param_name + "\"");
-    }
+    tp->second.value = *value;
   }
   else {
-    throw FileTypeException("Don`t set value " + *value + " for parameter \"" + param_name +
-                            "\". Parameter not exists.");
+    throw FileTypeException("Don`t set new value for parameter \"" + param_name + "\". Parameter not exists.");
   }
 }
 
@@ -151,16 +152,19 @@ void FileType::Impl::setParamUserValue(const UnicodeString& param_name, const Un
   setParamValue(param_name, value);
 }
 
-void FileType::Impl::setParamDescription(const UnicodeString& param_name,
-                                         const UnicodeString* t_description)
+void FileType::Impl::setParamDescription(const UnicodeString& param_name, const UnicodeString* value)
 {
-  auto tp = paramsHash.find(param_name);
+  const auto tp = paramsHash.find(param_name);
   if (tp != paramsHash.end()) {
-    tp->second.description.reset(new UnicodeString(*t_description));
+    if (value) {
+      tp->second.description = std::make_unique<UnicodeString>(*value);
+    }
+    else {
+      tp->second.description.reset();
+    }
   }
   else {
-    throw FileTypeException("Don`t set value " + *t_description +
-                            " for description of parameter \"" + param_name +
+    throw FileTypeException("Don`t set value for description of parameter \"" + param_name +
                             "\". Parameter not exists.");
   }
 }
@@ -170,18 +174,15 @@ size_t FileType::Impl::getParamCount() const
   return paramsHash.size();
 }
 
-double FileType::Impl::getPriority(const UnicodeString* fileName,
-                                   const UnicodeString* fileContent) const
+double FileType::Impl::getPriority(const UnicodeString* fileName, const UnicodeString* fileContent) const
 {
-  SMatches match {};
   double cur_prior {0};
   for (auto const& ftc : chooserVector) {
-    if (ftc.isFileName() && fileName != nullptr && ftc.getRE()->parse(fileName, &match)) {
-      cur_prior += ftc.getPriority();
+    if (ftc.isFileName()) {
+      cur_prior += ftc.calcPriority(fileName);
     }
-    else if (ftc.isFileContent() && fileContent != nullptr &&
-             ftc.getRE()->parse(fileContent, &match)) {
-      cur_prior += ftc.getPriority();
+    else if (ftc.isFileContent()) {
+      cur_prior += ftc.calcPriority(fileContent);
     }
   }
   return cur_prior;
