@@ -12,8 +12,7 @@ uUnicodeString Encodings::toUnicodeString(char* data, int32_t len)
   int32_t signatureLength;
   encoding = ucnv_detectUnicodeSignature(data, len, &signatureLength, &status);
   if (U_FAILURE(status)) {
-    logger->error("Encodings: Error \"{0}\" from ucnv_detectUnicodeSignature()\n",
-                  u_errorName(status));
+    COLORER_LOG_ERROR("Encodings: Error \"%\" from ucnv_detectUnicodeSignature()\n", u_errorName(status));
     throw Exception("Error from ucnv_detectUnicodeSignature");
   }
   if (encoding == nullptr) {
@@ -23,6 +22,11 @@ uUnicodeString Encodings::toUnicodeString(char* data, int32_t len)
   return std::make_unique<UnicodeString>(data + signatureLength, len - signatureLength, encoding);
 }
 
+uUnicodeString Encodings::fromUTF8(char* data, int32_t len)
+{
+  return std::make_unique<UnicodeString>(data , len , ENC_UTF8);
+}
+
 int Encodings::toUTF8Bytes(UChar wc, byte* dest)
 {
   int32_t len = 0;
