@@ -282,6 +282,7 @@ namespace oldfar
 	enum FARLISTFINDFLAGS
 	{
 		LIFIND_EXACTMATCH = 0x00000001,
+		LIFIND_KEEPAMPERSAND = 0x00000002,
 	};
 
 	struct FarListFind
@@ -569,6 +570,8 @@ namespace oldfar
 		PFLAGS_REALNAMES          = 0x00000020,
 		PFLAGS_NUMERICSORT        = 0x00000040,
 		PFLAGS_PANELLEFT          = 0x00000080,
+		PFLAGS_HL_MARKERS_NOSHOW  = 0x00000800,
+		PFLAGS_HL_MARKERS_NOALIGN = 0x00001000,
 	};
 
 	enum PANELINFOTYPE
@@ -1594,6 +1597,15 @@ namespace oldfar
 	//  crossed initial value specified in *CellsCount.
 	typedef size_t (WINAPI *FARSTRSIZEOFCELLS)(const char *Str, size_t CharsCount, size_t *CellsCount, BOOL RoundUp);
 
+	// Exports to file virtual terminal history of given VT console
+	//  con_hnd - NULL means active console, otherise - must be one of handles obtained from VTEnumBackground
+	//  flags - is a combination of VT_LOGEXPORT_* constants
+	//  file - is a file path to be exported, if it points to empty string (i.e. *file = 0) then
+	//    it MUST be buffer of size at least MAX_PATH (4096) characters and VT history log will be
+	//    exported to file at autogenerated temporary path that will be copied into that buffer
+	// Returns TRUE on success
+	typedef BOOL (WINAPI *FARAPIVT_LOGEXPORT)(HANDLE con_hnd, DWORD flags, const char *file);
+
 	typedef struct FarStandardFunctions
 	{
 		int StructSize;
@@ -1649,6 +1661,8 @@ namespace oldfar
 		FARBACKGROUNDTASK          BackgroundTask;
 		FARSTRCELLSCOUNT           StrCellsCount;
 		FARSTRSIZEOFCELLS          StrSizeOfCells;
+		FARAPIVT_ENUM_BACKGROUND   VTEnumBackground;
+		FARAPIVT_LOGEXPORT         VTLogExport;
 	} FARSTANDARDFUNCTIONS;
 
 	struct PluginStartupInfo
@@ -1755,6 +1769,8 @@ namespace oldfar
 		OPIF_EXTERNALDELETE          = 0x00002000,
 		OPIF_EXTERNALMKDIR           = 0x00004000,
 		OPIF_USEATTRHIGHLIGHTING     = 0x00008000,
+		OPIF_HL_MARKERS_NOSHOW       = 0x00020000,
+		OPIF_HL_MARKERS_NOALIGN      = 0x00040000,
 	};
 
 
