@@ -70,9 +70,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtcompletor.h"
 #include <limits>
 
-#include "farversion.h"
-#include <sys/utsname.h>
-
 CommandLine::CommandLine()
 	:
 	CmdStr(CtrlObject->Cp(), 0, true, CtrlObject->CmdHistory, 0,
@@ -909,215 +906,6 @@ void CommandLine::RedrawWithoutComboBoxMark()
 	DrawComboBoxMark(L' ');
 }
 
-void FarAbout(PluginManager &Plugins)
-{
-	int npl;
-	FARString fs, fs2;
-	MenuItemEx mi, mis;
-	mis.Flags = LIF_SEPARATOR;
-
-	VMenu ListAbout(L"far:about",nullptr,0,ScrY-4);
-	ListAbout.SetFlags(VMENU_SHOWAMPERSAND | VMENU_IGNORE_SINGLECLICK);
-	ListAbout.ClearFlags(VMENU_MOUSEREACTION);
-	//ListAbout.SetFlags(VMENU_WRAPMODE);
-	ListAbout.SetHelp(L"SpecCmd");//L"FarAbout");
-	ListAbout.SetBottomTitle(L"ESC or F10 to close, Ctrl-Alt-F - filtering");
-
-	fs.Format(L"         FAR2L Version: %s", FAR_BUILD);
-	ListAbout.AddItem(fs);
-	fs.Format(L"              Platform: %s", FAR_PLATFORM);
-	ListAbout.AddItem(fs);
-	fs.Format(L"               Backend: %ls", WinPortBackend());
-	ListAbout.AddItem(fs);
-	fs.Format(L"   ConsoleColorPalette: %u", WINPORT(GetConsoleColorPalette)(NULL) );
-	ListAbout.AddItem(fs);
-	fs.Format(L"                 Admin: %ls", Opt.IsUserAdmin ? Msg::FarTitleAddonsAdmin : L"-");
-	ListAbout.AddItem(fs);
-	//apiGetEnvironmentVariable("FARPID", fs2);
-	//fs = L"           PID: " + fs2;
-	fs.Format(L"                   PID: %lu", (unsigned long)getpid());
-	ListAbout.AddItem(fs);
-
-
-	ListAbout.AddItem(L"");
-	struct utsname un;
-	fs =      L"                 uname: ";
-	if (uname(&un)==0)
-		fs.AppendFormat(L"%s %s %s %s", un.sysname, un.release, un.version, un.machine);
-	ListAbout.AddItem(fs);
-	fs =      L"                  Host: " + (apiGetEnvironmentVariable("HOSTNAME", fs2) ? fs2 : L"???");
-	ListAbout.AddItem(fs);
-	fs =      L"                  User: " + (apiGetEnvironmentVariable("USER", fs2) ? fs2 : L"???");
-	ListAbout.AddItem(fs);
-	fs =      L"      XDG_SESSION_TYPE: " + (apiGetEnvironmentVariable("XDG_SESSION_TYPE", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L"                  TERM: " + (apiGetEnvironmentVariable("TERM", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L"             COLORTERM: " + (apiGetEnvironmentVariable("COLORTERM", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L"           GDK_BACKEND: " + (apiGetEnvironmentVariable("GDK_BACKEND", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L"       DESKTOP_SESSION: " + (apiGetEnvironmentVariable("DESKTOP_SESSION", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L"       WSL_DISTRO_NAME: " + (apiGetEnvironmentVariable("WSL_DISTRO_NAME", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-	fs =      L" WSL2_GUI_APPS_ENABLED: " + (apiGetEnvironmentVariable("WSL2_GUI_APPS_ENABLED", fs2) ? fs2 : L"");
-	ListAbout.AddItem(fs);
-
-	ListAbout.AddItem(L"");
-
-	//apiGetEnvironmentVariable("FARLANG", fs2);
-	fs =      L" Main | Help languages: " + Opt.strLanguage + L" | " + Opt.strHelpLanguage;
-	ListAbout.AddItem(fs);
-
-	fs.Format(L"  OEM | ANSI codepages: %u | %u", WINPORT(GetOEMCP)(), WINPORT(GetACP)() );
-	ListAbout.AddItem(fs);
-
-	ListAbout.AddItem(L"");
-
-	//apiGetEnvironmentVariable("FARHOME", fs2);
-	fs =      L"         Far directory: \"" + g_strFarPath.GetMB() + L"\"";
-	ListAbout.AddItem(fs);
-
-	fs.Format(L"      Config directory: \"%s\"", InMyConfig("",FALSE).c_str() );
-	ListAbout.AddItem(fs);
-
-	fs.Format(L"       Cache directory: \"%s\"", InMyCache("",FALSE).c_str() );
-	ListAbout.AddItem(fs);
-
-	fs.Format(L"        Temp directory: \"%s\"", InMyTemp("").c_str() );
-	ListAbout.AddItem(fs);
-
-	ListAbout.AddItem(L"");
-
-	npl = Plugins.GetPluginsCount();
-	fs.Format(L"    Number of plugins: %d", npl);
-	ListAbout.AddItem(fs);
-
-	for(int i = 0; i < npl; i++)
-	{
-		fs.Format(L"Plugin#%02d ",  i+1);
-		mis.strName = fs;
-		mi.PrefixLen = fs.GetLength()-1;
-
-		Plugin *pPlugin = Plugins.GetPlugin(i);
-		if(pPlugin == nullptr) {
-			ListAbout.AddItem(&mis);
-			mi.strName = fs + L"!!! ERROR get plugin";
-			ListAbout.AddItem(&mi);
-			continue;
-		}
-		mis.strName = fs + PointToName(pPlugin->GetModuleName());
-		ListAbout.AddItem(&mis);
-
-		mi.strName = fs + pPlugin->GetModuleName();
-		ListAbout.AddItem(&mi);
-
-		mi.strName = fs + L"Settings Name: " + pPlugin->GetSettingsName();
-		ListAbout.AddItem(&mi);
-
-		int iFlags;
-		PluginInfo pInfo{};
-		KeyFileReadHelper kfh(PluginsIni());
-		FARString fsCommandPrefix = L"";
-		FARString fsDiskMenuStrings = L"";
-		FARString fsPluginMenuStrings = L"";
-		FARString fsPluginConfigStrings = L"";
-
-		if (pPlugin->CheckWorkFlags(PIWF_CACHED)) {
-			iFlags = kfh.GetUInt(pPlugin->GetSettingsName(), "Flags", 0);
-			fsCommandPrefix = kfh.GetString(pPlugin->GetSettingsName(), "CommandPrefix", L"");
-			for (int j = 0; ; j++) {
-				const auto &key_name = StrPrintf("DiskMenuString%d", j);
-				/*if (!kfh.HasKey(key_name))
-					break;*/
-				fs2 = kfh.GetString(pPlugin->GetSettingsName(), key_name, "");
-				if( fs2.IsEmpty() )
-					break;
-				fsDiskMenuStrings.AppendFormat(L" %d=\"%ls\" ", j+1, fs2.CPtr());
-			}
-			for (int j = 0; ; j++) {
-				const auto &key_name = StrPrintf("PluginMenuString%d", j);
-				/*if (!kfh.HasKey(key_name))
-					break;*/
-				fs2 = kfh.GetString(pPlugin->GetSettingsName(), key_name, "");
-				if( fs2.IsEmpty() )
-					break;
-				fsPluginMenuStrings.AppendFormat(L" %d=\"%ls\" ", j+1, fs2.CPtr());
-			}
-			for (int j = 0; ; j++) {
-				const auto &key_name = StrPrintf("PluginConfigString%d", j);
-				/*if (!kfh.HasKey(key_name))
-					break;*/
-				fs2 = kfh.GetString(pPlugin->GetSettingsName(), key_name, "");
-				if( fs2.IsEmpty() )
-					break;
-				fsPluginConfigStrings.AppendFormat(L" %d=\"%ls\" ", j+1, fs2.CPtr());
-			}
-		}
-		else {
-			if (pPlugin->GetPluginInfo(&pInfo)) {
-				iFlags = pInfo.Flags;
-				fsCommandPrefix = pInfo.CommandPrefix;
-				for (int j = 0; j < pInfo.DiskMenuStringsNumber; j++)
-					fsDiskMenuStrings.AppendFormat(L" %d=\"%ls\"", j+1, pInfo.DiskMenuStrings[j]);
-				for (int j = 0; j < pInfo.PluginMenuStringsNumber; j++)
-					fsPluginMenuStrings.AppendFormat(L" %d=\"%ls\"", j+1, pInfo.PluginMenuStrings[j]);
-				for (int j = 0; j < pInfo.PluginConfigStringsNumber; j++)
-					fsPluginConfigStrings.AppendFormat(L" %d=\"%ls\"", j+1, pInfo.PluginConfigStrings[j]);
-			}
-			else
-				iFlags = -1;
-		}
-
-		mi.strName.Format(L"%ls     %s Cached  %s Loaded ",
-			fs.CPtr(),
-			pPlugin->CheckWorkFlags(PIWF_CACHED) ? "[x]" : "[ ]",
-			pPlugin->GetFuncFlags() & PICFF_LOADED ? "[x]" : "[ ]");
-		ListAbout.AddItem(&mi);
-
-		if (iFlags >= 0) {
-			mi.strName.Format(L"%lsF11: %s Panel   %s Dialog  %s Viewer  %s Editor ",
-				fs.CPtr(),
-				iFlags & PF_DISABLEPANELS ? "[ ]" : "[x]",
-				iFlags & PF_DIALOG ? "[x]" : "[ ]",
-				iFlags & PF_VIEWER ? "[x]" : "[ ]",
-				iFlags & PF_EDITOR ? "[x]" : "[ ]");
-			ListAbout.AddItem(&mi);
-		}
-
-		mi.strName.Format(L"%ls     %s EditorInput ", fs.CPtr(), pPlugin->HasProcessEditorInput() ? "[x]" : "[ ]");
-		ListAbout.AddItem(&mi);
-
-		if ( !fsDiskMenuStrings.IsEmpty() ) {
-			mi.strName = fs + L"    DiskMenuStrings:" + fsDiskMenuStrings;
-			ListAbout.AddItem(&mi);
-		}
-		if ( !fsPluginMenuStrings.IsEmpty() ) {
-			mi.strName = fs + L"  PluginMenuStrings:" + fsPluginMenuStrings;
-			ListAbout.AddItem(&mi);
-		}
-		if ( !fsPluginConfigStrings.IsEmpty() ) {
-			mi.strName = fs + L"PluginConfigStrings:" + fsPluginConfigStrings;
-			ListAbout.AddItem(&mi);
-		}
-		if ( !fsCommandPrefix.IsEmpty() ) {
-			mi.strName.Format(L"%ls      CommandPrefix: \"%ls\"", fs.CPtr(), fsCommandPrefix.CPtr());
-			ListAbout.AddItem(&mi);
-		}
-		
-	}
-
-	ListAbout.SetPosition(-1, -1, 0, 0);
-	int iListExitCode = 0;
-	do {
-		ListAbout.Process();
-		iListExitCode = ListAbout.GetExitCode();
-		if (iListExitCode>=0)
-			ListAbout.ClearDone(); // no close after select item by ENTER or mouse click
-	} while(iListExitCode>=0);
-}
-
 bool CommandLine::ProcessFarCommands(const wchar_t *CmdLine)
 {
 	bool b_far, b_edit = false, b_view = false;
@@ -1143,6 +931,7 @@ bool CommandLine::ProcessFarCommands(const wchar_t *CmdLine)
 	}
 
 	if (b_far && str_command == L"far:about") {
+		void FarAbout(PluginManager &Plugins);
 		FarAbout(CtrlObject->Plugins);
 		return true; // prefix correct and was processed
 	}
@@ -1153,11 +942,22 @@ bool CommandLine::ProcessFarCommands(const wchar_t *CmdLine)
 			: 0 );
 	if (p > 0) {
 		p = str_command.find_first_not_of(L" \t", p);
-		if (p != std::string::npos) // after spaces found filename
-			new FileEditor(
-				std::make_shared<FileHolder>( str_command.substr(p,std::string::npos).c_str() ),
-				CP_AUTODETECT, FFILEEDIT_CANNEWFILE | FFILEEDIT_ENABLEF6);
-		else
+		if (p != std::string::npos) { // after spaces found filename or command
+			if (str_command[p]==L'<') { // redirect command
+				p = str_command.find_first_not_of(L" \t", p+1);
+				if (p != std::string::npos) {
+					new FileEditor(
+						std::make_shared<FileHolder>(
+							ExecuteCommandAndGrabItsOutput( str_command.substr(p,std::string::npos).c_str() ) ),
+						CP_AUTODETECT, FFILEEDIT_ENABLEF6 | FFILEEDIT_DISABLEHISTORY);
+				}
+			}
+			else // filename
+				new FileEditor(
+					std::make_shared<FileHolder>( str_command.substr(p,std::string::npos).c_str() ),
+					CP_AUTODETECT, FFILEEDIT_CANNEWFILE | FFILEEDIT_ENABLEF6);
+		}
+		else // new empty file
 			new FileEditor(
 				std::make_shared<FileHolder>( Msg::NewFileName.CPtr() ),
 				CP_AUTODETECT, FFILEEDIT_CANNEWFILE | FFILEEDIT_ENABLEF6);
@@ -1170,14 +970,35 @@ bool CommandLine::ProcessFarCommands(const wchar_t *CmdLine)
 			: 0 );
 	if (p > 0) {
 		p = str_command.find_first_not_of(L" \t", p);
-		if (p != std::string::npos) // after spaces found filename
-			new FileViewer(std::make_shared<FileHolder>( str_command.substr(p,std::string::npos).c_str() ), TRUE);
+		if (p != std::string::npos) { // after spaces found filename or command
+			if (str_command[p]==L'<') { // redirect command
+				p = str_command.find_first_not_of(L" \t", p+1);
+				if (p != std::string::npos) {
+					new FileViewer(std::make_shared<FileHolder>(
+							ExecuteCommandAndGrabItsOutput( str_command.substr(p,std::string::npos).c_str() ) ),
+					TRUE/*EnableSwitch*/, TRUE/*DisableHistory*/, FALSE/*DisableEdit*/);
+				}
+			}
+			else // filename
+				new FileViewer(std::make_shared<FileHolder>( str_command.substr(p,std::string::npos).c_str() ),
+					TRUE/*EnableSwitch*/, FALSE/*DisableHistory*/, FALSE/*DisableEdit*/);
+		}
 		return true; // anyway prefix correct and was processed
 	}
 
 	return false; // not found any available prefixes
 }
 
+const CHAR_INFO *CommandLine::GetBackgroundScreen(int &W, int &H)
+{
+	if (!BackgroundScreen)
+		return NULL;
+
+	W = (BackgroundScreen->X2 - BackgroundScreen->X1) + 1;
+	H = (BackgroundScreen->Y2 - BackgroundScreen->Y1) + 1;
+	return BackgroundScreen->GetBufferAddress();
+}
+
 CmdLineVisibleScope::CmdLineVisibleScope()
 {
 	if (CtrlObject && CtrlObject->CmdLine && !CtrlObject->CmdLine->IsVisible()) {
@@ -1193,4 +1014,3 @@ CmdLineVisibleScope::~CmdLineVisibleScope()
 		cp->UpdateCmdLineVisibility();
 	}
 }
-
