@@ -203,7 +203,7 @@ bool FileFilter::FilterEdit()
 			case KEY_BS: {
 				int SelPos = FilterList.GetSelectPos();
 
-				if (SelPos == (int)FilterData.getCount())
+				if (SelPos < 0 || SelPos == (int)FilterData.getCount())
 					break;
 
 				auto Check = FilterList.GetCheck(SelPos);
@@ -235,6 +235,8 @@ bool FileFilter::FilterEdit()
 			}
 			case KEY_F4: {
 				int SelPos = FilterList.GetSelectPos();
+				if (SelPos < 0)
+					break;
 
 				if (SelPos < (int)FilterData.getCount()) {
 					if (FileFilterConfig(FilterData.getItem(SelPos))) {
@@ -261,8 +263,11 @@ bool FileFilter::FilterEdit()
 			case KEY_NUMPAD0:
 			case KEY_INS:
 			case KEY_F5: {
-				size_t SelPos = FilterList.GetSelectPos();
-				size_t SelPos2 = SelPos + 1;
+				int pos = FilterList.GetSelectPos();
+				if (pos < 0)
+					break;
+				size_t SelPos = pos;
+				size_t SelPos2 = pos + 1;
 
 				SelPos = Min(FilterData.getCount(), SelPos);
 
@@ -311,6 +316,8 @@ bool FileFilter::FilterEdit()
 			case KEY_NUMDEL:
 			case KEY_DEL: {
 				int SelPos = FilterList.GetSelectPos();
+				if (SelPos < 0)
+					break;
 
 				if (SelPos < (int)FilterData.getCount()) {
 					FARString strQuotedTitle = FilterData.getItem(SelPos)->GetTitle();
