@@ -63,16 +63,40 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #elif !defined(__FreeBSD__) && !defined(__DragonFly__) && !defined(__HAIKU__)
 #include <sys/sysinfo.h>
 #endif
+#include <sys/statvfs.h>
 
 static int LastDizWrapMode = -1;
 static int LastDizWrapType = -1;
 static int LastDizShowScrollbar = -1;
 
+enum InfoListSectionStateIndex
+{
+	ILSS_DISKINFO,
+	ILSS_MEMORYINFO,
+	ILSS_GITINFO,
+	/*ILSS_DIRDESCRIPTION,
+	ILSS_PLDESCRIPTION,
+	ILSS_POWERSTATUS,*/
+
+	ILSS_SIZE
+};
+
+struct InfoList::InfoListSectionState
+{
+	bool Show;   // раскрыть/свернуть?
+	int Y;       // Где? (<0 - отсутствует)
+};
+
 InfoList::InfoList()
 	:
-	DizView(nullptr), PrevMacroMode(-1)
+	DizView(nullptr), PrevMacroMode(-1), SectionState(ILSS_SIZE)
 {
 	Type = INFO_PANEL;
+	for (auto& i: SectionState)
+	{
+		i.Show = true;
+		i.Y = -1;
+	}
 	if (LastDizWrapMode < 0) {
 		LastDizWrapMode = Opt.ViOpt.ViewerIsWrap;
 		LastDizWrapType = Opt.ViOpt.ViewerWrap;
@@ -103,17 +127,51 @@ FARString &InfoList::GetTitle(FARString &strTitle, int SubLen, int TruncSize)
 	return strTitle;
 }
 
+void InfoList::DrawTitle(const wchar_t *Str, int Id, int CurY)
+{
+	SetFarColor(COL_PANELBOX);
+	DrawSeparator(CurY);
+	SetFarColor(COL_PANELTEXT);
+
+	if (Str != nullptr && *Str) {
+		FARString strTitle;
+		strTitle.Format(L" %ls ", Str);
+		TruncStr(strTitle, X2 - X1 - 3);
+		GotoXY(X1 + (X2 - X1 + 1 - (int)strTitle.GetLength()) / 2, CurY);
+		PrintText(strTitle);
+	}
+	if (Id >= 0 && Id < ILSS_SIZE ) {
+		GotoXY(X1 + 1, CurY);
+		PrintText(SectionState[Id].Show ? L"[-]" : L"[+]");
+		SectionState[Id].Y = CurY;
+	}
+}
+
+inline void InfoList::DrawTitle(FarLangMsg MsgID, int Id, int CurY)
+{
+	DrawTitle(MsgID.CPtr(), Id, CurY);
+}
+
+void InfoList::ClearTitles()
+{
+	for (int i=0; i<ILSS_SIZE; i++)
+		SectionState[i].Y = -1;
+}
+
+
 void InfoList::DisplayObject()
 {
 	FARString strTitle;
 	FARString strOutStr;
+	FARString strRealDir;
 	Panel *AnotherPanel;
 	//	FARString strDriveRoot;
-	FARString strVolumeName, strFileSystemName;
+	FARString strVolumeName, strFileSystemName, strFileSystemMountPoint;
 	DWORD MaxNameLength, FileSystemFlags;
 	DWORD64 VolumeNumber;
 	FARString strDiskNumber;
 	CloseFile();
+	ClearTitles();
 
 	Box(X1, Y1, X2, Y2, FarColorToReal(COL_PANELBOX), DOUBLE_BOX);
 	SetScreen(X1 + 1, Y1 + 1, X2 - 1, Y2 - 1, L' ', FarColorToReal(COL_PANELTEXT));
@@ -141,159 +199,282 @@ void InfoList::DisplayObject()
 		PrintInfo(CachedUserName());
 	}
 
-	/* #2 - disk info */
-
-	SetFarColor(COL_PANELBOX);
-	DrawSeparator(CurY);
-	SetFarColor(COL_PANELTEXT);
+	/* #2 - disk / plugin info */
 
 	AnotherPanel = CtrlObject->Cp()->GetAnotherPanel(this);
 	AnotherPanel->GetCurDir(strCurDir);
 
-	if (strCurDir.IsEmpty())
-		apiGetCurrentDirectory(strCurDir);
+	/* #2a.1 - disk info */
+	if (AnotherPanel->GetMode() != PLUGIN_PANEL) {
 
-	fprintf(stderr, "apiGetVolumeInformation: %ls\n", strCurDir.CPtr());
-	if (apiGetVolumeInformation(strCurDir, &strVolumeName, &VolumeNumber, &MaxNameLength, &FileSystemFlags,
-				&strFileSystemName)) {
-		//		strTitle=FARString(L" ")+DiskType+L" "+Msg::InfoDisk+L" "+(strDriveRoot)+L" ("+strFileSystemName+L") ";
-		strTitle = FARString(L" ") + L" (" + strFileSystemName + L") ";
+		if (strCurDir.IsEmpty())
+			apiGetCurrentDirectory(strCurDir);
 
-		strDiskNumber.Format(L"%08X-%08X", (DWORD)(VolumeNumber >> 32), (DWORD)(VolumeNumber & 0xffffffff));
-	} else						// Error!
-		strTitle = strCurDir;	// strDriveRoot;
+		ConvertNameToReal(strCurDir, strRealDir);
 
-	TruncStr(strTitle, X2 - X1 - 3);
-	GotoXY(X1 + (X2 - X1 + 1 - (int)strTitle.GetLength()) / 2, CurY++);
-	PrintText(strTitle);
+		fprintf(stderr, "apiGetVolumeInformation: %ls\n", strRealDir.CPtr());
+		bool b_info = apiGetVolumeInformation(strRealDir, &strVolumeName, &VolumeNumber, &MaxNameLength, &FileSystemFlags,
+					&strFileSystemName, &strFileSystemMountPoint);
+		if (b_info) {
+			//		strTitle=FARString(L" ")+DiskType+L" "+Msg::InfoDisk+L" "+(strDriveRoot)+L" ("+strFileSystemName+L") ";
+			strTitle = L"(" + strFileSystemName + L")";
 
-	/* #3 - disk info: size */
+			strDiskNumber.Format(L"%08X-%08X", (DWORD)(VolumeNumber >> 32), (DWORD)(VolumeNumber & 0xffffffff));
+		} else						// Error!
+			strTitle = strCurDir;	// strDriveRoot;
 
-	uint64_t TotalSize, TotalFree, UserFree;
+		DrawTitle(strTitle.CPtr(), ILSS_DISKINFO, CurY++);
+		if (SectionState[ILSS_DISKINFO].Show) {
+			/* #2a.2 - disk info: size */
 
-	if (apiGetDiskSize(strCurDir, &TotalSize, &TotalFree, &UserFree)) {
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoDiskTotal);
-		InsertCommas(TotalSize, strOutStr);
-		PrintInfo(strOutStr);
+			uint64_t TotalSize, TotalFree, UserFree;
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoDiskFree);
-		InsertCommas(UserFree, strOutStr);
-		PrintInfo(strOutStr);
+			if (apiGetDiskSize(strCurDir, &TotalSize, &TotalFree, &UserFree)) {
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoDiskTotal);
+				InsertCommas(TotalSize, strOutStr);
+				PrintInfo(strOutStr);
+
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoDiskFree);
+				InsertCommas(UserFree, strOutStr);
+				PrintInfo(strOutStr);
+			}
+
+			/* #2a.3 - disk info: label & SN */
+
+			if (!strVolumeName.IsEmpty()) {
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoDiskLabel);
+				PrintInfo(strVolumeName);
+			}
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoDiskNumber);
+			PrintInfo(strDiskNumber);
+
+			// new fields
+			CurY++; // skip line
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoDiskCurDir);
+			PrintInfo(strCurDir);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoDiskRealDir);
+			PrintInfo(strRealDir);
+
+			if (b_info) {
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoDiskMountPoint);
+				PrintInfo(strFileSystemMountPoint);
+
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoDiskMaxFilenameLength);
+				strTitle.Format(L"%lu", (unsigned long) MaxNameLength);
+				PrintInfo(strTitle);
+
+				strOutStr.Clear();
+#ifdef ST_RDONLY		/* Mount read-only.  */
+				strOutStr += (FileSystemFlags & ST_RDONLY) ? "ro" : "rw";
+#endif
+#ifdef ST_NOSUID		/* Ignore suid and sgid bits.  */
+				if (FileSystemFlags & ST_NOSUID)
+					strOutStr += ",nosuid";
+#endif
+#ifdef ST_NODEV			/* Disallow access to device special files.  */
+				if (FileSystemFlags & ST_NODEV)
+					strOutStr += ",nodev";
+#endif
+#ifdef ST_NOEXEC		/* Disallow program execution.  */
+				if (FileSystemFlags & ST_NOEXEC)
+					strOutStr += ",noexec";
+#endif
+#ifdef ST_SYNCHRONOUS	/* Writes are synced at once.  */
+				if (FileSystemFlags & ST_SYNCHRONOUS)
+					strOutStr += ",sync";
+#endif
+#ifdef ST_MANDLOCK		/* Allow mandatory locks on an FS.  */
+				if (FileSystemFlags & ST_MANDLOCK)
+					strOutStr += ",mandlock";
+#endif
+#ifdef ST_WRITE			/* Write on file/directory/symlink.  */
+				if (FileSystemFlags & ST_WRITE)
+					strOutStr += ",write";
+#endif
+#ifdef ST_APPEND		/* Append-only file.  */
+				if (FileSystemFlags & ST_APPEND)
+					strOutStr += ",append";
+#endif
+#ifdef ST_IMMUTABLE		/* Immutable file.  */
+				if (FileSystemFlags & ST_IMMUTABLE)
+					strOutStr += ",immutable";
+#endif
+#ifdef ST_NOATIME		/* Do not update access times.  */
+				if (FileSystemFlags & ST_NOATIME)
+					strOutStr += ",noatime";
+#endif
+#ifdef ST_NODIRATIME	/* Do not update directory access times.  */
+				if (FileSystemFlags & ST_NODIRATIME)
+					strOutStr += ",nodiratime";
+#endif
+#ifdef ST_RELATIME		/* Update atime relative to mtime/ctime.  */
+				if (FileSystemFlags & ST_RELATIME)
+					strOutStr += ",relatime";
+#endif
+#ifdef ST_NOSYMFOLLOW
+				if (FileSystemFlags & ST_NOSYMFOLLOW)
+					strOutStr += ",nosymfollow";
+#endif
+				if (!strOutStr.IsEmpty()) {
+					GotoXY(X1 + 2, CurY++);
+					PrintText(Msg::InfoDiskFlags);
+					PrintInfo(strOutStr);
+				}
+			}
+
+		}
+	}
+	/* 2b - plugin */
+	else {
+		DrawTitle(Msg::InfoPluginTitle, ILSS_DISKINFO, CurY++);
+		if (SectionState[ILSS_DISKINFO].Show) {
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginStartDir);
+			PrintInfo(strCurDir);
+
+			HANDLE hPlugin = AnotherPanel->GetPluginHandle();
+			if (hPlugin != INVALID_HANDLE_VALUE) {
+				PluginHandle *ph = (PluginHandle *)hPlugin;
+				GotoXY(X1 + 2, CurY++);
+				PrintText(Msg::InfoPluginModuleName);
+				PrintInfo(PointToName(ph->pPlugin->GetModuleName()));
+			}
+
+			OpenPluginInfo Info;
+			AnotherPanel->GetOpenPluginInfo(&Info);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginHostFile);
+			PrintInfo(Info.HostFile);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginCurDir);
+			PrintInfo(Info.CurDir);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginPanelTitle);
+			PrintInfo(Info.PanelTitle);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginFormat);
+			PrintInfo(Info.Format);
+
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPluginShortcutData);
+			PrintInfo(Info.ShortcutData);
+		}
 	}
 
-	/* #4 - disk info: label & SN */
-
-	if (!strVolumeName.IsEmpty()) {
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoDiskLabel);
-		PrintInfo(strVolumeName);
-	}
-
-	GotoXY(X1 + 2, CurY++);
-	PrintText(Msg::InfoDiskNumber);
-	PrintInfo(strDiskNumber);
-
-	/* #4 - memory info */
-
-	SetFarColor(COL_PANELBOX);
-	DrawSeparator(CurY);
-	SetFarColor(COL_PANELTEXT);
-	strTitle = Msg::InfoMemory;
-	TruncStr(strTitle, X2 - X1 - 3);
-	GotoXY(X1 + (X2 - X1 + 1 - (int)strTitle.GetLength()) / 2, CurY++);
-	PrintText(strTitle);
+	/* #3 - memory info */
+	DrawTitle(Msg::InfoMemory, ILSS_MEMORYINFO, CurY++);
+	if (SectionState[ILSS_MEMORYINFO].Show) {
 
 #ifdef __APPLE__
-	unsigned long long totalram;
-	vm_size_t page_size;
-	unsigned long long freeram;
-	int ret_sc;
+		unsigned long long totalram;
+		vm_size_t page_size;
+		unsigned long long freeram;
+		int ret_sc;
 
-	// ret_sc =  (sysctlbyname("hw.memsize", &totalram, &ulllen, NULL, 0) ? 1 : 0);
-	ret_sc = (KERN_SUCCESS != _host_page_size(mach_host_self(), &page_size) ? 1 : 0);
+		// ret_sc =  (sysctlbyname("hw.memsize", &totalram, &ulllen, NULL, 0) ? 1 : 0);
+		ret_sc = (KERN_SUCCESS != _host_page_size(mach_host_self(), &page_size) ? 1 : 0);
 
-	mach_msg_type_number_t count = HOST_VM_INFO_COUNT;
-	vm_statistics_data_t vmstat;
+		mach_msg_type_number_t count = HOST_VM_INFO_COUNT;
+		vm_statistics_data_t vmstat;
 
-	ret_sc+= (KERN_SUCCESS != host_statistics(mach_host_self(), HOST_VM_INFO, (host_info_t)&vmstat, &count)
-					? 1
-					: 0);
-	totalram =
-			(vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count) * page_size;
-	freeram = vmstat.free_count * page_size;
+		ret_sc+= (KERN_SUCCESS != host_statistics(mach_host_self(), HOST_VM_INFO, (host_info_t)&vmstat, &count)
+						? 1
+						: 0);
+		totalram =
+				(vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count) * page_size;
+		freeram = vmstat.free_count * page_size;
 
-	// double total = vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count;
-	// double wired = vmstat.wire_count;
-	// double active = vmstat.active_count;
-	// double inactive = vmstat.inactive_count;
-	// double free = vmstat.free_count;
+		// double total = vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count;
+		// double wired = vmstat.wire_count;
+		// double active = vmstat.active_count;
+		// double inactive = vmstat.inactive_count;
+		// double free = vmstat.free_count;
 
-	if (!ret_sc) {
-		DWORD dwMemoryLoad = 100 - ToPercent64(freeram, totalram);
+		if (!ret_sc) {
+			DWORD dwMemoryLoad = 100 - ToPercent64(freeram, totalram);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryLoad);
-		strOutStr.Format(L"%d%%", dwMemoryLoad);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryLoad);
+			strOutStr.Format(L"%d%%", dwMemoryLoad);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryTotal);
-		InsertCommas(totalram, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryTotal);
+			InsertCommas(totalram, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryFree);
-		InsertCommas(freeram, strOutStr);
-		PrintInfo(strOutStr);
-	}
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryFree);
+			InsertCommas(freeram, strOutStr);
+			PrintInfo(strOutStr);
+		}
 
 #elif !defined(__FreeBSD__) && !defined(__DragonFly__) && !defined(__HAIKU__)
-	struct sysinfo si = {};
-	if (sysinfo(&si) == 0) {
-		DWORD dwMemoryLoad = 100 - ToPercent64(si.freeram + si.freeswap, si.totalram + si.totalswap);
+		struct sysinfo si = {};
+		if (sysinfo(&si) == 0) {
+			DWORD dwMemoryLoad = 100 - ToPercent64(si.freeram + si.freeswap, si.totalram + si.totalswap);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryLoad);
-		strOutStr.Format(L"%d%%", dwMemoryLoad);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryLoad);
+			strOutStr.Format(L"%d%%", dwMemoryLoad);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryTotal);
-		InsertCommas(si.totalram, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryTotal);
+			InsertCommas(si.totalram, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoMemoryFree);
-		InsertCommas(si.freeram, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoMemoryFree);
+			InsertCommas(si.freeram, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoSharedMemory);
-		InsertCommas(si.sharedram, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoSharedMemory);
+			InsertCommas(si.sharedram, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoBufferMemory);
-		InsertCommas(si.bufferram, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoBufferMemory);
+			InsertCommas(si.bufferram, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoPageFileTotal);
-		InsertCommas(si.totalswap, strOutStr);
-		PrintInfo(strOutStr);
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPageFileTotal);
+			InsertCommas(si.totalswap, strOutStr);
+			PrintInfo(strOutStr);
 
-		GotoXY(X1 + 2, CurY++);
-		PrintText(Msg::InfoPageFileFree);
-		InsertCommas(si.freeswap, strOutStr);
-		PrintInfo(strOutStr);
-	}
+			GotoXY(X1 + 2, CurY++);
+			PrintText(Msg::InfoPageFileFree);
+			InsertCommas(si.freeswap, strOutStr);
+			PrintInfo(strOutStr);
+		}
 #endif
-	/* #5 - description */
+	}
 
+	/* #4 - git status */
+	ShowGitStatus(CurY);
+
+	/* #5 - dir description */
 	ShowDirDescription(CurY);
-	ShowPluginDescription();
+
+	/* #6 - plugin description */
+	ShowPluginDescription(CurY);
 }
 
 int64_t InfoList::VMProcess(MacroOpcode OpCode, void *vParam, int64_t iParam)
@@ -408,6 +589,20 @@ int InfoList::ProcessMouse(MOUSE_EVENT_RECORD *MouseEvent)
 {
 	int RetCode;
 
+	if ((MouseEvent->dwButtonState & FROM_LEFT_1ST_BUTTON_PRESSED)
+			&& (MouseEvent->dwEventFlags != MOUSE_MOVED))
+	{
+		for (auto &elem : SectionState)
+		{
+			if (elem.Y<0 || MouseEvent->dwMousePosition.Y != elem.Y)
+				continue;
+
+			elem.Show = !elem.Show;
+			Redraw();
+			return TRUE;
+		}
+	}
+
 	if (Panel::PanelProcessMouse(MouseEvent, RetCode))
 		return (RetCode);
 
@@ -479,96 +674,117 @@ void InfoList::PrintInfo(FarLangMsg MsgID)
 	PrintInfo(MsgID.CPtr());
 }
 
+void InfoList::ShowGitStatus(int &YPos)
+{
+	Panel *AnotherPanel = CtrlObject->Cp()->GetAnotherPanel(this);
+
+	if (AnotherPanel->GetMode() != FILE_PANEL)
+		return;
+
+	FARString strDir;
+	AnotherPanel->GetCurDir(strDir);
+	do {
+		FARString strGit = strDir + L"/.git";
+		struct stat s;
+		if (stat(strGit.GetMB().c_str(), &s) == 0) {
+			fprintf(stderr, "GIT: %ls\n", strGit.CPtr());
+			std::vector<std::wstring> lines;
+			std::string cmd = "git -C \"";
+			cmd+= EscapeCmdStr(Wide2MB(strDir.CPtr()));
+			cmd+= "\" status -s -b";
+
+			if (POpen(lines, cmd.c_str())) {
+				// text " git status " in separator
+				DrawTitle(L"git status -s -b", ILSS_GITINFO, YPos++);
+				if (SectionState[ILSS_GITINFO].Show) {
+					// print git root dir
+					GotoXY(X1 + 2, YPos++);
+					PrintText(Msg::InfoGitRootDir);
+					PrintInfo(strDir);
+					// print result of git status 
+					for (const auto &l : lines) {
+						GotoXY(X1 + 2, YPos++);
+						PrintText(l.c_str());
+					}
+				}
+			}
+			break;
+		}
+	} while (CutToSlash(strDir, true));
+}
+
 void InfoList::ShowDirDescription(int YPos)
 {
 	Panel *AnotherPanel = CtrlObject->Cp()->GetAnotherPanel(this);
-	DrawSeparator(YPos);
+	if (AnotherPanel->GetMode() != FILE_PANEL)
+		return;
 
-	if (AnotherPanel->GetMode() == FILE_PANEL) {
-		FARString strDir;
-		AnotherPanel->GetCurDir(strDir);
+	DrawTitle(nullptr, -1/*ILSS_DIRDESCRIPTION*/, YPos);
 
-		do {
-			FARString strGit = strDir + L"/.git";
-			struct stat s;
-			if (stat(strGit.GetMB().c_str(), &s) == 0) {
-				fprintf(stderr, "GIT: %ls\n", strGit.CPtr());
-				std::vector<std::wstring> lines;
-				std::string cmd = "git -C \"";
-				cmd+= EscapeCmdStr(Wide2MB(strDir.CPtr()));
-				cmd+= "\" status";
+	FARString strDir;
+	AnotherPanel->GetCurDir(strDir);
 
-				if (POpen(lines, cmd.c_str())) {
-					for (const auto &l : lines) {
-						GotoXY(X1 + 2, ++YPos);
-						PrintText(l.c_str());
-					}
-					DrawSeparator(++YPos);
-				}
-				break;
-			}
-		} while (CutToSlash(strDir, true));
+	if (!strDir.IsEmpty())
+		AddEndSlash(strDir);
 
-		AnotherPanel->GetCurDir(strDir);
+	FARString strArgName;
+	const wchar_t *NamePtr = Opt.InfoPanel.strFolderInfoFiles;
 
-		if (!strDir.IsEmpty())
-			AddEndSlash(strDir);
+	while ((NamePtr = GetCommaWord(NamePtr, strArgName))) {
+		FARString strFullDizName;
+		strFullDizName = strDir;
+		strFullDizName+= strArgName;
+		FAR_FIND_DATA_EX FindData;
 
-		FARString strArgName;
-		const wchar_t *NamePtr = Opt.InfoPanel.strFolderInfoFiles;
-
-		while ((NamePtr = GetCommaWord(NamePtr, strArgName))) {
-			FARString strFullDizName;
-			strFullDizName = strDir;
-			strFullDizName+= strArgName;
-			FAR_FIND_DATA_EX FindData;
-
-			if (!apiGetFindDataEx(strFullDizName, FindData, FIND_FILE_FLAG_CASE_INSENSITIVE)) {
-				continue;
-			}
-
-			CutToSlash(strFullDizName, false);
-			strFullDizName+= FindData.strFileName;
-
-			if (OpenDizFile(strFullDizName, YPos))
-				return;
+		if (!apiGetFindDataEx(strFullDizName, FindData, FIND_FILE_FLAG_CASE_INSENSITIVE)) {
+			continue;
 		}
+
+		CutToSlash(strFullDizName, false);
+		strFullDizName+= FindData.strFileName;
+
+		if (OpenDizFile(strFullDizName, YPos))
+			return;
 	}
 
 	CloseFile();
+
+	strDir = L" ";
+	strDir += Msg::InfoDescription;
+	strDir += L" ";
+	TruncStr(strDir, X2 - X1 - 3);
+	GotoXY(X1 + (X2 - X1 - (int)strDir.GetLength()) / 2, YPos++);
 	SetFarColor(COL_PANELTEXT);
-	GotoXY(X1 + 2, YPos + 1);
+	PrintText(strDir);
+
+	SetFarColor(COL_PANELTEXT);
+	GotoXY(X1 + 2, YPos);
 	PrintText(Msg::InfoDizAbsent);
 }
 
-void InfoList::ShowPluginDescription()
+void InfoList::ShowPluginDescription(int YPos)
 {
-	Panel *AnotherPanel;
-	static wchar_t VertcalLine[2] = {BoxSymbols[BS_V2], 0};
-	AnotherPanel = CtrlObject->Cp()->GetAnotherPanel(this);
+	Panel *AnotherPanel = CtrlObject->Cp()->GetAnotherPanel(this);
 
 	if (AnotherPanel->GetMode() != PLUGIN_PANEL)
 		return;
 
-	CloseFile();
 	OpenPluginInfo Info;
 	AnotherPanel->GetOpenPluginInfo(&Info);
 
-	for (int I = 0; I < Info.InfoLinesNumber; I++) {
-		int Y = Y2 - Info.InfoLinesNumber + I;
+	if (Info.InfoLinesNumber <= 0) {
+		DrawTitle(Msg::InfoPluginDescription, -1/*ILSS_DIRDESCRIPTION*/, YPos++);
+		GotoXY(X1 + 2, YPos);
+		PrintText(Msg::InfoPluginAbsent);
+		return;
+	}
 
-		if (Y <= Y1)
-			continue;
+	if (!Info.InfoLines[0].Separator) // show default, if plugin info start without its own separator
+		DrawTitle(Msg::InfoPluginDescription, -1/*ILSS_DIRDESCRIPTION*/, YPos++);
 
+	for (int I = 0; I < Info.InfoLinesNumber && YPos < Y2; I++, YPos++) {
 		const InfoPanelLine *InfoLine = &Info.InfoLines[I];
-		GotoXY(X1, Y);
-		SetFarColor(COL_PANELBOX);
-		Text(VertcalLine);
-		SetFarColor(COL_PANELTEXT);
-		FS << fmt::Cells() << fmt::Expand(X2 - X1 - 1) << L"";
-		SetFarColor(COL_PANELBOX);
-		Text(VertcalLine);
-		GotoXY(X1 + 2, Y);
+		GotoXY(X1 + 2, YPos);
 
 		if (InfoLine->Separator) {
 			FARString strTitle;
@@ -576,11 +792,13 @@ void InfoList::ShowPluginDescription()
 			if (InfoLine->Text && *InfoLine->Text)
 				strTitle.Append(L" ").Append(InfoLine->Text).Append(L" ");
 
-			DrawSeparator(Y);
+			DrawSeparator(YPos);
 			TruncStr(strTitle, X2 - X1 - 3);
-			GotoXY(X1 + (X2 - X1 - (int)strTitle.GetLength()) / 2, Y);
+			GotoXY(X1 + (X2 - X1 - (int)strTitle.GetLength()) / 2, YPos);
+			SetFarColor(COL_PANELTEXT);
 			PrintText(strTitle);
 		} else {
+			SetFarColor(COL_PANELTEXT);
 			PrintText(NullToEmpty(InfoLine->Text));
 			PrintInfo(NullToEmpty(InfoLine->Data));
 		}
