@@ -1601,6 +1601,7 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 	ProcessingPluginCommand++;
 	FilePanels *FPanels = CtrlObject->Cp();
 	PluginCommand = Command;
+	auto DestFilePanel = dynamic_cast<FileList*>(this);
 
 	switch (Command) {
 		case FCTL_SETVIEWMODE:
@@ -1703,6 +1704,8 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 				} PFLAGS[] = {
 						{&Opt.ShowHidden, PFLAGS_SHOWHIDDEN},
 						{&Opt.Highlight,  PFLAGS_HIGHLIGHT },
+						{&Opt.ShowFilenameMarks,   PFLAGS_HL_MARKERS_NOSHOW },
+						{&Opt.FilenameMarksAlign,  PFLAGS_HL_MARKERS_NOALIGN },
 				};
 				DWORD Flags = 0;
 
@@ -1724,7 +1727,6 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 			}
 
 			if (GetType() == FILE_PANEL) {
-				FileList *DestFilePanel = (FileList *)this;
 				static int Reenter = 0;
 
 				if (!Reenter && Info->Plugin) {
@@ -1741,6 +1743,12 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 					if (PInfo.Flags & OPIF_USECRC32)
 						Info->Flags|= PFLAGS_USECRC32;
 
+					if (PInfo.Flags & OPIF_HL_MARKERS_NOSHOW)		// (?) condition added by analogy:
+						Info->Flags|= PFLAGS_HL_MARKERS_NOSHOW;		//  may not be completely correct
+
+					if (PInfo.Flags & OPIF_HL_MARKERS_NOALIGN)		// (?) condition added by analogy:
+						Info->Flags|= PFLAGS_HL_MARKERS_NOALIGN;	//  may not be completely correct
+
 					Reenter--;
 				}
 
@@ -1763,7 +1771,6 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 				GetCurDir(strTemp);
 
 			if (GetType() == FILE_PANEL) {
-				FileList *DestFilePanel = (FileList *)this;
 				static int Reenter = 0;
 
 				if (!Reenter && GetMode() == PLUGIN_PANEL) {
@@ -1800,7 +1807,7 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 
 			if (GetType() == FILE_PANEL) {
 				FARString strColumnTypes, strColumnWidths;
-				((FileList *)this)->PluginGetColumnTypesAndWidths(strColumnTypes, strColumnWidths);
+				DestFilePanel->PluginGetColumnTypesAndWidths(strColumnTypes, strColumnWidths);
 
 				if (Command == FCTL_GETCOLUMNTYPES) {
 					if (Param1 && Param2)
@@ -1817,26 +1824,29 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 			break;
 
 		case FCTL_GETPANELITEM: {
-			Result = (int)((FileList *)this)->PluginGetPanelItem(Param1, (PluginPanelItem *)Param2);
+			if (DestFilePanel)
+				Result = (int)DestFilePanel->PluginGetPanelItem(Param1, (PluginPanelItem *)Param2);
 			break;
 		}
 
 		case FCTL_GETSELECTEDPANELITEM: {
-			Result = (int)((FileList *)this)->PluginGetSelectedPanelItem(Param1, (PluginPanelItem *)Param2);
+			if (DestFilePanel)
+				Result = (int)DestFilePanel->PluginGetSelectedPanelItem(Param1, (PluginPanelItem *)Param2);
 			break;
 		}
 
 		case FCTL_GETCURRENTPANELITEM: {
-			PanelInfo Info;
-			FileList *DestPanel = ((FileList *)this);
-			DestPanel->PluginGetPanelInfo(Info);
-			Result = (int)DestPanel->PluginGetPanelItem(Info.CurrentItem, (PluginPanelItem *)Param2);
+			if (DestFilePanel) {
+				PanelInfo Info;
+				DestFilePanel->PluginGetPanelInfo(Info);
+				Result = (int)DestFilePanel->PluginGetPanelItem(Info.CurrentItem, (PluginPanelItem *)Param2);
+			}
 			break;
 		}
 
 		case FCTL_BEGINSELECTION: {
 			if (GetType() == FILE_PANEL) {
-				((FileList *)this)->PluginBeginSelection();
+				DestFilePanel->PluginBeginSelection();
 				Result = TRUE;
 			}
 			break;
@@ -1844,7 +1854,7 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 
 		case FCTL_SETSELECTION: {
 			if (GetType() == FILE_PANEL) {
-				((FileList *)this)->PluginSetSelection(Param1, Param2 ? true : false);
+				DestFilePanel->PluginSetSelection(Param1, Param2 ? true : false);
 				Result = TRUE;
 			}
 			break;
@@ -1852,7 +1862,7 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 
 		case FCTL_CLEARSELECTION: {
 			if (GetType() == FILE_PANEL) {
-				reinterpret_cast<FileList *>(this)->PluginClearSelection(Param1);
+				DestFilePanel->PluginClearSelection(Param1);
 				Result = TRUE;
 			}
 			break;
@@ -1860,7 +1870,7 @@ int Panel::SetPluginCommand(int Command, int Param1, LONG_PTR Param2)
 
 		case FCTL_ENDSELECTION: {
 			if (GetType() == FILE_PANEL) {
-				((FileList *)this)->PluginEndSelection();
+				DestFilePanel->PluginEndSelection();
 				Result = TRUE;
 			}
 			break;
