@@ -71,6 +71,8 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "RegExp.hpp"
 #include "console.hpp"
 #include "InterThreadCall.hpp"
+#include "vtshell.h"
+#include "vtlog.h"
 
 #include "farversion.h"
 
@@ -2338,3 +2340,49 @@ DWORD WINAPI farGetCurrentDirectory(DWORD Size, wchar_t *Buffer)
 
 	return static_cast<DWORD>(strCurDir.GetLength() + 1);
 }
+
+SIZE_T farAPIVTEnumBackground(HANDLE *con_hnds, SIZE_T count)
+{
+	if (count == 0) {
+		return VTShell_Count();
+	}
+	VTInfos vts;
+	VTShell_Enum(vts);
+	for (size_t i = 0; i < count && i < vts.size(); ++i) {
+		con_hnds[i] = vts[i].con_hnd;
+	}
+	return vts.size();
+}
+
+
+BOOL farAPIVTLogExportA(HANDLE con_hnd, DWORD vth_flags, const char *file)
+{
+	const auto &saved_path = VTLog::GetAsFile(con_hnd,
+		(vth_flags & VT_LOGEXPORT_COLORED) != 0,
+		(vth_flags & VT_LOGEXPORT_WITH_SCREENLINES) != 0,
+		file);
+	if (saved_path.empty())
+		return FALSE;
+
+	if (!*file) {
+		strncpy((char *)file, saved_path.c_str(), MAX_PATH);
+	}
+
+	return TRUE;
+}
+
+BOOL farAPIVTLogExportW(HANDLE con_hnd, DWORD vth_flags, const wchar_t *file)
+{
+	const auto &saved_path = VTLog::GetAsFile(con_hnd,
+		(vth_flags & VT_LOGEXPORT_COLORED) != 0,
+		(vth_flags & VT_LOGEXPORT_WITH_SCREENLINES) != 0,
+		Wide2MB(file).c_str());
+	if (saved_path.empty())
+		return FALSE;
+
+	if (!*file) {
+		wcsncpy((wchar_t *)file, StrMB2Wide(saved_path).c_str(), MAX_PATH);
+	}
+
+	return TRUE;
+}
