@@ -16,6 +16,8 @@ struct IVTShell
 	virtual void OnMouseExpectation(MouseExpectation mex, bool enabled) = 0;
 	virtual void OnBracketedPasteExpectation(bool enabled)              = 0;
 	virtual void OnWin32InputMode(bool enabled)                         = 0;
+	virtual void SetKittyFlags(int flags)                               = 0;
+	virtual int  GetKittyFlags()                                        = 0;
 	virtual void OnApplicationProtocolCommand(const char *str)          = 0;
 	virtual bool OnOSCommand(int id, std::string &str)                  = 0;
 	virtual void InjectInput(const char *str)                           = 0;
